<?php
/**
 * Business Web functions and definitions
 *
 * @package Business Web
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
function content($limit) {
$content = explode(' ', get_the_excerpt(), $limit);
if (count($content)>=$limit) {
array_pop($content);
$content = implode(" ",$content).'...';
} else {
$content = implode(" ",$content);
}	
$content = preg_replace('/\[.+\]/','', $content);
$content = apply_filters('the_content', $content);
$content = str_replace(']]>', ']]&gt;', $content);
return $content;
}


if ( ! function_exists( 'business_web_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function business_web_setup() {

	if ( ! isset( $content_width ) )
		$content_width = 640; /* pixels */

	load_theme_textdomain( 'business-web', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'title-tag' );
	add_filter('widget_text', 'do_shortcode');
	add_image_size('homepage-thumb',240,145,true);	
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'business-web' ),
		'footer' => __( 'Footer Menu', 'business-web' ),
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );
	add_editor_style( 'editor-style.css' );
}
endif; // business_web_setup
add_action( 'after_setup_theme', 'business_web_setup' );

function business_web_widgets_init() {

	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'business-web' ),
		'description'   => __( 'Appears on blog page sidebar', 'business-web' ),
		'id'            => 'sidebar-1',
		'before_widget' => '',		
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3><aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar Main', 'business-web' ),
		'description'   => __( 'Appears on page sidebar', 'business-web' ),
		'id'            => 'sidebar-main',
		'before_widget' => '',		
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3><aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
	) );	
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 1', 'business-web' ),
		'description'   => __( 'Appears on footer', 'business-web' ),
		'id'            => 'footer-1',
		'before_widget' => '<div id="%1$s" class="widget-column-1">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 2', 'business-web' ),
		'description'   => __( 'Appears on footer', 'business-web' ),
		'id'            => 'footer-2',
		'before_widget' => '<div id="%1$s" class="widget-column-2">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 3', 'business-web' ),
		'description'   => __( 'Appears on footer', 'business-web' ),
		'id'            => 'footer-3',
		'before_widget' => '<div id="%1$s" class="widget-column-3">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 4', 'business-web' ),
		'description'   => __( 'Appears on footer', 'business-web' ),
		'id'            => 'footer-4',
		'before_widget' => '<div id="%1$s" class="widget-column-4">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	
	register_sidebar( array(
		'name'          => __( 'Sidebar Contact Page', 'business-web' ),
		'description'   => __( 'Appears on contact page', 'business-web' ),
		'id'            => 'sidebar-contact',
		'before_widget' => '<aside class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Header Widget', 'business-web' ),
		'description'   => __( 'Appears on header', 'business-web' ),
		'id'            => 'header-widget',
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '<h6 style="display:none">',
		'after_title'   => '</h6>',
	) );
		

}
add_action( 'widgets_init', 'business_web_widgets_init' );

define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/inc/' );
require_once get_template_directory() . '/inc/options-framework.php';

function business_web_scripts() {
	
	wp_enqueue_style( 'business_web-gfonts-roboto', '//fonts.googleapis.com/css?family=Roboto:400,100,300,500,700' );	
	wp_enqueue_style( 'business_web-gfonts-robotocondensed', '//fonts.googleapis.com/css?family=Roboto+Condensed:400,300,300italic,400italic,700' );	
	wp_enqueue_style( 'business_web-gfonts-lato', '//fonts.googleapis.com/css?family=Lato:400,100,100italic,300,300italic,400italic,700,700italic,900,900italic' );
	wp_enqueue_style( 'business_web-gfonts-ptsans', '//fonts.googleapis.com/css?family=PT+Sans:400,400italic,700,700italic' );	
	wp_enqueue_style( 'business_web-gfonts-raleway', '//fonts.googleapis.com/css?family=Raleway:400,100,200,300,500,600,700,900,800' );
	
	

	if( of_get_option('bodyfontface',true) != '' ){
		wp_enqueue_style( 'business_web-gfonts-body', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('bodyfontface',true)) );
	}
	if( of_get_option('logofontface',true) != '' ){
		wp_enqueue_style( 'business_web-gfonts-logo', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('logofontface',true)) );
	}
	if ( of_get_option('navfontface', true) != '' ) {
		wp_enqueue_style( 'business_web-gfonts-nav', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('navfontface',true)) );
	}
	if ( of_get_option('headfontface', true) != '' ) {
		wp_enqueue_style( 'business_web-gfonts-heading', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('headfontface',true)) );
	}
	
	if ( of_get_option('hdrtopfontface', true) != '' ) {
		wp_enqueue_style( 'business_web-gfonts-hdrtopfontface', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('hdrtopfontface',true)) );
	}
	
	if ( of_get_option('hdrtopfontface', true) != '' ) {
		wp_enqueue_style( 'business_web-gfonts-hdrtopfontface', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('hdrtopfontface',true)) );
	}
	

	wp_enqueue_style( 'business-web-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'business-web-editor-style', get_template_directory_uri().'/editor-style.css' );
	wp_enqueue_style( 'business-web-base-style', get_template_directory_uri().'/css/default.css' );	
	if ( is_home() || is_front_page() ) { 
	wp_enqueue_style( 'business-web-nivo-style', get_template_directory_uri().'/css/nivo-slider.css' );
	wp_enqueue_script( 'business-web-nivo-slider', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	}	
	
	wp_enqueue_script( 'business-web-customscripts', get_template_directory_uri() . '/js/custom.js', array('jquery') );
	wp_enqueue_style( 'business-web-font-awesome-style', get_template_directory_uri().'/css/font-awesome.css' );	
	wp_enqueue_script( 'business-web-testimonialsminjs', get_template_directory_uri().'/testimonialsrotator/js/jquery.quovolver.min.js', array('jquery') );
	wp_enqueue_style( 'business-web-testimonialslider-style', get_template_directory_uri().'/testimonialsrotator/js/tm-rotator.css' );	
	wp_enqueue_style( 'business-web-responsive-style', get_template_directory_uri().'/css/theme-responsive.css' );		
	wp_enqueue_style( 'business-web-owl-style', get_template_directory_uri().'/testimonialsrotator/js/owl.carousel.css' );
	wp_enqueue_script( 'business-web-owljs', get_template_directory_uri().'/testimonialsrotator/js/owl.carousel.js', array('jquery') );	
	wp_enqueue_style( 'business-web-animation-style', get_template_directory_uri().'/css/animation.css' );
	wp_enqueue_script( 'business-web-counterup', get_template_directory_uri().'/counter/js/jquery.counterup.min.js', array('jquery') );
	wp_enqueue_script( 'business-web-waypoints', get_template_directory_uri().'/counter/js/waypoints.min.js', array('jquery') );
	
	// mixitup script
	wp_enqueue_style( 'business-web-mixitup-style', get_template_directory_uri().'/mixitup/style-mixitup.css' );
	wp_enqueue_script( 'business-web-jquery_013-script', get_template_directory_uri() . '/mixitup/jquery_013.js', array('jquery') );
	wp_enqueue_script( 'business-web-jquery_003-script', get_template_directory_uri() . '/mixitup/jquery_003.js', array('jquery') );
	wp_enqueue_script( 'business-web-screen-script', get_template_directory_uri() . '/mixitup/screen.js', array('jquery') );
	// prettyPhoto script
	wp_enqueue_style( 'business-web-prettyphoto-style', get_template_directory_uri().'/mixitup/prettyPhotoe735.css' );
	wp_enqueue_script( 'business-web-prettyphoto-script', get_template_directory_uri() . '/mixitup/jquery.prettyPhoto5152.js', array('jquery') );
	
	//Client Logo Rotator
	wp_enqueue_style( 'business-web-flexiselcss', get_template_directory_uri().'/css/flexiselcss.css' );	
	wp_enqueue_script( 'business-web-flexisel', get_template_directory_uri() . '/js/jquery.flexisel.js', array('jquery') );
	
	if( of_get_option('scrollanimation',true) != true) {
		wp_enqueue_style( 'business-web-animation-style', get_template_directory_uri().'/css/animation-style.css' );
		wp_enqueue_script( 'business-web-custom-animation', get_template_directory_uri() . '/js/custom-animation.js', array('jquery') );	
	}
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'business_web_scripts' );

function media_css_hook(){
	
	?>
    	
    	<script>
			jQuery(window).bind('scroll', function() {
	var wwd = jQuery(window).width();
	if( wwd > 939 ){
		var navHeight = jQuery( window ).height() - 550;
		<?php if( of_get_option('headstick',true) != true) { ?>
		if (jQuery(window).scrollTop() > navHeight) {
			jQuery(".header").addClass('fixed');			
		}else {
			jQuery(".header").removeClass('fixed');			
		}
		<?php } ?>
	}
});

<?php if ( is_home() || is_front_page() ) { ?> 			
jQuery(window).load(function() {
 jQuery('#slider').nivoSlider({
        	effect:'<?php echo of_get_option('slideefect',true); ?>', //sliceDown, sliceDownLeft, sliceUp, sliceUpLeft, sliceUpDown, sliceUpDownLeft, fold, fade, random, slideInRight, slideInLeft, boxRandom, boxRain, boxRainReverse, boxRainGrow, boxRainGrowReverse
		  	animSpeed: <?php echo of_get_option('slideanim',true); ?>,
			pauseTime: <?php echo of_get_option('slidepause',true); ?>,
			directionNav: <?php echo of_get_option('slidenav',true); ?>,
			controlNav: <?php echo of_get_option('slidepage',true); ?>,
			pauseOnHover: <?php echo of_get_option('slidepausehover',true); ?>,
    });
});
<?php } ?>

// Testimonials  function
jQuery(document).ready(function() { 
   jQuery('#testimonials .quotes').quovolver({
      children    : 'li',
      transitionSpeed : 600,
      autoPlay    : <?php echo of_get_option('testimonialsautoplay',true); ?>,
	  autoPlaySpeed: <?php echo of_get_option('testimonialsrotatingspeed',true); ?>,
      equalHeight   : false,
      navPosition   : 'above',
      navPrev     : true,
      navNext     : true,
      navNum      : true,
      navText     : false,
      navTextContent  : 'Quote @a of @b'
    });    
  });
  

jQuery(document).ready(function() {
  
  jQuery('.link').on('click', function(event){
    var $this = jQuery(this);
    if($this.hasClass('clicked')){
      $this.removeAttr('style').removeClass('clicked');
    } else{
      $this.css('background','#7fc242').addClass('clicked');
    }
  });
 
});
		</script>
<?php 
}
add_action('wp_head','media_css_hook');  


function business_web_custom_head_codes() { 
	if ( function_exists('of_get_option') ){
		if ( of_get_option('style2', true) != '' ) {
			echo "<style>". esc_html( of_get_option('style2', true) ) ."</style>";
		}
		echo "<style>";
		if ( of_get_option('bodyfontface', true) != '') {
			echo 'body, .price-table{font-family:\''. esc_html( of_get_option('bodyfontface', true) ) .'\', sans-serif;}';
		}
		if ( of_get_option('bodyfontcolor', true) != '' ) {
			echo 'body, .contact-form-section .address,  .accordion-box .acc-content{color:'. esc_html( of_get_option('bodyfontcolor', true) ) .';}';
		}
		if( of_get_option('bodyfontsize',true) != ''){
			echo "body{font-size:".of_get_option('bodyfontsize',true)."}";
		}
		if( of_get_option('logofontface',true) != '' || of_get_option('logofontcolor',true) != '' || of_get_option('logofontsize',true) != ''){
			echo ".logo h1, .logo a {font-family:".of_get_option('logofontface').";color:".of_get_option('logofontcolor',true).";font-size:".of_get_option('logofontsize',true)."}";
		}
		if( of_get_option('logofontcolor',true) != '' ){
			echo ".header span.tagline{color:".of_get_option('logofontcolor',true).";}";
		}		
		if( of_get_option('hdrtopfontface',true) != '' || of_get_option('hdrtopfontcolor',true) != '' || of_get_option('hdrtopfontsize',true) != '' || of_get_option('hdrtopbgcolor',true) != ''){
			echo ".signin_wrap {font-family:".of_get_option('hdrtopfontface').";color:".of_get_option('hdrtopfontcolor',true).";font-size:".of_get_option('hdrtopfontsize',true)."; background-color:".of_get_option('hdrtopbgcolor',true)."}";
		}		
		if ( of_get_option('navfontface', true) != '' || of_get_option('navfontsize',true) != '' ) {
			echo '.header-nav ul{font-family:\''. esc_html( of_get_option('navfontface', true) ) .'\', sans-serif;font-size:'.of_get_option('navfontsize',true).'}';
		}
		if ( of_get_option('navfontcolor', true) != '' ) {
			echo '.header-nav ul li a, .header-nav ul li.current_page_item ul li a{color:'. esc_html( of_get_option('navfontcolor', true) ) .';}';
		}
		
		if ( of_get_option('navhovercolor', true) != '') {
			echo '.header-nav ul li a:hover, .header-nav ul li.current_page_item a, .header-nav ul li.current_page_item ul li a:hover, .header-nav ul li.current-menu-ancestor a.parent{ color:'. esc_html( of_get_option('navhovercolor', true) ) .';}';
		}	
		
		if( of_get_option('menufontstyle',true) != '' ){
			echo ".fixed .header-inner .nav ul li a span, .header-nav ul li a span{font-style:".of_get_option('menufontstyle',true)."}";
		}
				
		if( of_get_option('sectitlesize',true) != '' ){
			echo "h2.section_title{font-size:".of_get_option('sectitlesize',true)."}";
		}		
		if ( of_get_option('headfontface', true) != '' || of_get_option('sectitlecolor',true) != '' ) {
			echo 'h1, h2, h3, h4, h5, h6, h2.section_title{font-family:\''. esc_html( of_get_option('headfontface', true) ) .'\', sans-serif;color:'.of_get_option('sectitlecolor',true).'}';
		}				
		if ( of_get_option('linkcolor', true) != '' ) {
			echo 'a{color:'. esc_html( of_get_option('linkcolor', true) ) .';}';
		}
		if ( of_get_option('linkhovercolor', true) != '' ) {
			echo 'a:hover{color:'. esc_html( of_get_option('linkhovercolor', true) ) .';}';
		}			
		if( of_get_option('foottitlecolor', true) != '' || of_get_option('ftfontsize', true) != '' || of_get_option('foottitleborder', true) != '' ){
			echo ".footer h5{color:".of_get_option('foottitlecolor', true)."; font-size:".of_get_option('ftfontsize', true)."; border-color:".of_get_option('foottitleborder', true)."; }";
		}		
		if( of_get_option('footdesccolor', true) != ''){
			echo ".footer{color:".of_get_option('footdesccolor', true).";}";
		}					
		if( of_get_option('copycolor', true) != ''){
			echo ".copyright-txt{color:".of_get_option('copycolor',true)."}";
		}
		if( of_get_option('designcolor', true) != ''){
			echo ".design-by{color:".of_get_option('designcolor',true)."}";
		}		
		if ( of_get_option('headerbg', true) != '' ) {
			echo ".header, .header-nav ul li:hover > ul{background-color:".of_get_option('headerbg',true).";}";
		}			
		if( of_get_option('socialfontcolor',true) != '' ){
			echo ".social-icons a{color:".of_get_option('socialfontcolor',true)."; }";
		}
		if( of_get_option('socialfonthvcolor',true) != ''){
			echo ".social-icons a:hover{color:".of_get_option('socialfonthvcolor',true)."; }";
		}
		if( of_get_option('socialfonthvcolor',true) != ''){
			echo "#footer-wrapper .social-icons a:hover{border-color:".of_get_option('socialfonthvcolor',true)."; }";
		}
		if( of_get_option('socialstyle',true) != ''){
			echo "#footer-wrapper .social-icons a{border-radius:".of_get_option('socialstyle', true)."%; }";
		}
					
		if( of_get_option('btnbgcolor',true) != '' || of_get_option('btntxtcolor', true) != '' ){
			echo "#commentform input#submit, input.search-submit, .post-password-form input[type=submit], p.read-more a, .accordion-box h2:before, .pagination ul li span, .pagination ul li a{background-color:".of_get_option('btnbgcolor',true)."; color:". of_get_option('btntxtcolor', true) ."; }";
		}
		if( of_get_option('btnbghvcolor',true) != '' || of_get_option('btntxthvcolor', true) != '' ){
			echo "#commentform input#submit:hover, input.search-submit:hover, .post-password-form input[type=submit]:hover, p.read-more a:hover, .pagination ul li .current, .pagination ul li a:hover{background-color:".of_get_option('btnbghvcolor',true)."; color:". esc_html( of_get_option('btntxthvcolor', true) ) .";}";
		}
		
		if( of_get_option('slidebtncolor', true) != '' ){
			echo ".button{ color:". of_get_option('slidebtncolor', true) ."; border:1px solid ". of_get_option('slidebtncolor', true) ."; }";
		}
		
		if( of_get_option('slidebtncolorhv', true) != '' ){
			echo ".button:hover{ color:". of_get_option('slidebtncolorhv', true) ."; border-color: ". of_get_option('slidebtncolorhv', true) ."; }";
		}
		
		
		if( of_get_option('searchbgcolor',true) != ''){
			echo ".searchbox-icon, .searchbox-submit {background-color:".of_get_option('searchbgcolor',true)."; }";
		}
		
		if ( of_get_option('widgettitlebgcolor', true) != '' || of_get_option('wdgttitleccolor', true) != '' ) {
			echo "h3.widget-title{background-color:".of_get_option('widgettitlebgcolor', true)."; color:".of_get_option('wdgttitleccolor', true).";}";
		}
		if ( of_get_option('footerbgcolor', true) != '' ) {
			echo "#footer-wrapper{background-color:".of_get_option('footerbgcolor', true)."; }";
		}			
		if ( of_get_option('footermenucolor', true) != '' ) {
			echo ".footer ul li a{color:".of_get_option('footermenucolor', true)."; }";
		}
		
		if ( of_get_option('footermenucurrent', true) != '' ) {
			echo ".footer ul li a:hover, .footer ul li.current_page_item a, .phone-no strong{color:".of_get_option('footermenucurrent', true)."; }";
		}			
		if ( of_get_option('copybgcolor', true) != '' ) {
			echo '.copyright-wrapper{background-color:'. esc_html( of_get_option('copybgcolor', true) ) .';}';
		}						
		if( of_get_option('sldpagebg',true) != ''){
			echo ".nivo-controlNav a{background-color:".of_get_option('sldpagebg',true)."}";
		}
		if( of_get_option('sldpagehvbg',true) != ''){
			echo ".nivo-controlNav a.active{background-color:".of_get_option('sldpagehvbg',true)."}";
		}				
		if( of_get_option('sidebarfontcolor',true) != '' || of_get_option('sidebarliaborder', true) != '' ){
			echo "#sidebar ul li a{color:".of_get_option('sidebarfontcolor',true)."; border-bottom:1px dashed ".of_get_option('sidebarliaborder',true)."}";
		}		
		if( of_get_option('sidebarfonthvcolor',true) != '' ){
			echo "#sidebar ul li a:hover{color:".of_get_option('sidebarfonthvcolor',true)."; }";
		}	
				
		if (  of_get_option('slidetitlecolor', true) != '' || of_get_option('slidetitlefontsize', true) != '') {
		echo ".slide_info h2{ color:".of_get_option('slidetitlecolor', true)."; font-size:".of_get_option('slidetitlefontsize', true).";}";
		}		
		if ( of_get_option('slidedesccolor', true) != '' || of_get_option('slidedescfontsize', true) != '') {
		echo ".slide_info p{ color:".of_get_option('slidedesccolor', true)."; font-size:".of_get_option('slidedescfontsize', true).";}";
		}
				
		if ( of_get_option('tmn_titlefontcolor', true) != '' ) {
		echo "#testimonials ul li h6{ color: ".of_get_option('tmn_titlefontcolor', true)."; }";
		}		
		if ( of_get_option('copylinks', true) != '' ) {
		echo ".copyright-wrapper a{ color: ".of_get_option('copylinks', true)."; }";
		}	
		if ( of_get_option('copylinkshover', true) != '' ) {
		echo ".copyright-wrapper a:hover{ color: ".of_get_option('copylinkshover', true)."; }";
		}	
		if ( of_get_option('footerpoststitle', true) != '' ) {
		echo ".recent-post h6{ color: ".of_get_option('footerpoststitle', true)."; }";
		}		
		if ( of_get_option('footerpoststitlehv', true) != '' ) {
		echo ".recent-post h6:hover{ color: ".of_get_option('footerpoststitlehv', true)."; }";
		}				
		if ( of_get_option('teamtitlecolor', true) != '' ) {
		echo ".teammember-list h5, .member-desination{ color:".of_get_option('teamtitlecolor', true)."; }";
		}	
		if ( of_get_option('teamparacolor', true) != '' ) {
		echo ".teammember-list p{ color:".of_get_option('teamparacolor', true)."; }";
		}	
		if ( of_get_option('teamtitlehovercolor', true) != '' ) {
		echo ".teammember-list:hover h5{ color:".of_get_option('teamtitlehovercolor', true)."; }";
		}
		if ( of_get_option('teamtitlehovercolor', true) != '' ) {
		echo ".member-desination{ border-color:".of_get_option('teamtitlehovercolor', true)."; }";
		}
			
		if ( of_get_option('teamsicolor', true) != '' ) {
		echo ".member-social-icon a{ color:".of_get_option('teamsicolor', true)."; }";
		}
		if ( of_get_option('teamsicolorhv', true) != '' ) {
		echo ".member-social-icon a:hover{ color:".of_get_option('teamsicolorhv', true)."; }";
		}
		if ( of_get_option('teamsiconborder', true) != '' ) {
		echo ".member-social-icon{ border-top:1px solid ".of_get_option('teamsiconborder', true)."; }";
		}		
		if ( of_get_option('iframeborder', true) != '') {
		echo "iframe{ border:1px solid ".of_get_option('iframeborder', true)."; }";
		}		
		if ( of_get_option('sidebarbgcolor', true) != '' ) {
		echo "aside.widget{ background-color:".of_get_option('sidebarbgcolor', true)."; }";
		}	
	
		if ( of_get_option('readmorebutton', true) != '' ) {
		echo ".view-all-btn a{ border:1px solid ".of_get_option('readmorebutton', true)."; border-left:5px solid ".of_get_option('readmorebutton', true)."; }";
		}		
		if ( of_get_option('readmorebuttonhv', true) != '' ) {
		echo ".view-all-btn a:hover{ border-color:".of_get_option('readmorebuttonhv', true)."; }";
		}			

		if ( of_get_option('togglemenu', true) != '' ) {
		echo ".toggle a{ background-color:".of_get_option('togglemenu', true)."; }";
		}
		if ( of_get_option('phoneiconcolor', true) != '' ) {
		echo ".signin_wrap .right .fa{ color:".of_get_option('phoneiconcolor', true)."; }";
		}
		if ( of_get_option('secborderbottom', true) != '' ) {
		echo "#wrapsecond, #ourclient{border-bottom:1px solid ".of_get_option('secborderbottom', true)."; }";
		}		
		if ( of_get_option('srvciconbg', true) != '' || of_get_option('srvciconfc', true) != '' ) {
		echo ".services-wrap .one_fourth .fa{background-color: ".of_get_option('srvciconbg', true)."; color: ".of_get_option('srvciconfc', true)."; }";
		}		
		if ( of_get_option('srvciconbghv', true) != '' || of_get_option('srvciconfchv', true) != '' ) {
		echo ".services-wrap .one_fourth:hover .fa{background-color: ".of_get_option('srvciconbghv', true)."; color: ".of_get_option('srvciconfchv', true)."; }";
		}		
		if ( of_get_option('srvclinkcolor', true) != '' ) {
		echo ".services-wrap .one_fourth a.rdmore{ color: ".of_get_option('srvclinkcolor', true)."; }";
		}		
		if ( of_get_option('srvclinkcolorhv', true) != '' ) {
		echo ".services-wrap .one_fourth:hover a.rdmore{ color: ".of_get_option('srvclinkcolorhv', true)."; border:1px solid ".of_get_option('srvclinkcolorhv', true)."; }";
		}		
		if ( of_get_option('titlecolorhv', true) != '' ) {
		echo ".services-wrap .one_fourth:hover h4{ color: ".of_get_option('titlecolorhv', true)."; }";
		}
		
		if ( of_get_option('tmnpagerbg', true) != '' ) {
		echo "ol.nav-numbers li a{background-color: ".of_get_option('tmnpagerbg', true)."; border:2px solid ".of_get_option('tmnpagerbg', true)."; }";
		}
		
		if ( of_get_option('tmnpagerbghv', true) != '' ) {
		echo "ol.nav-numbers li.active a{background-color: ".of_get_option('tmnpagerbghv', true)."; border:2px solid ".of_get_option('tmnpagerbg', true)."; }";
		}
		if ( of_get_option('headerborder', true) != '' ) {
		echo ".header{border-color:".of_get_option('headerborder', true)."; }";
		}
		
		if ( of_get_option('galleryfilterbg', true) != '' || of_get_option('galleryfilterborder', true) != '' ) {
		echo "ul.portfoliofilter li a{background-color: ".of_get_option('galleryfilterbg', true)."; border-color: ".of_get_option('galleryfilterborder', true)."; }";
		}
		
		if ( of_get_option('galleryfilterbghv', true) != '' || of_get_option('galleryfilteractivecolor', true) != '' ) {
		echo "ul.portfoliofilter li a.selected, ul.portfoliofilter li:hover a, ul.portfoliofilter li a:hover{background-color: ".of_get_option('galleryfilterbghv', true)."; border-color: ".of_get_option('galleryfilterbghv', true)."; color: ".of_get_option('galleryfilteractivecolor', true).";  }";
		}
		
		if ( of_get_option('pagebxbtnfontcolor', true) != '' || of_get_option('pagebxmorebtnborder', true) != '' ) {
		echo ".pagemore{ color: ".of_get_option('pagebxbtnfontcolor', true)."; border-color: ".of_get_option('pagebxmorebtnborder', true)."; }";
		}
		
		if ( of_get_option('pagebxbtnbghv', true) != '' || of_get_option('pagebxbtnfontcolorhv', true) != '' ) {
		echo ".fourbox:hover .pagemore{background-color: ".of_get_option('pagebxbtnbghv', true)."; color: ".of_get_option('pagebxbtnfontcolorhv', true)."; border-color: ".of_get_option('pagebxbtnbghv', true)."; }";
		}
				if ( of_get_option('pagebxttlfontcolor', true) != '' ) {
		echo ".fourbox h3{ color: ".of_get_option('pagebxttlfontcolor', true)."; }";
		}		
		if ( of_get_option('pagebxttlfontcolorhv', true) != '' ) {
		echo ".fourbox:hover h3{ color: ".of_get_option('pagebxttlfontcolorhv', true)."; }";
		}
		
		if ( of_get_option('acctitlebgcolor', true) != '' ) {
		echo ".fourbox:hover .pagemore{background-color: ".of_get_option('acctitlebgcolor', true).";}";
		}
		
		if ( of_get_option('acctitlebgcoloractive', true) != '' ) {
		echo ".accordion-box h2.active{background-color: ".of_get_option('acctitlebgcoloractive', true).";}";
		}
		
		if ( of_get_option('tabtitlebgcoloractive', true) != '' ) {
		echo ".tabs-wrapper ul.tabs li a.selected{background-color: ".of_get_option('tabtitlebgcoloractive', true).";}";
		}
		if ( of_get_option('tsmlfontcolor', true) != '' ) {
		echo "#testimonials ul li{ color: ".of_get_option('tsmlfontcolor', true)."; }";
		}
		
		if ( of_get_option('tgmenuresponsivebg', true) != '' ) {
		echo "@media screen and (max-width: 1169px){.header-nav{background-color: ".of_get_option('tgmenuresponsivebg', true).";}}";
		}	
		
		echo "</style>";
	}
}
add_action('wp_head', 'business_web_custom_head_codes');


function business_web_pagination() {
	global $wp_query;
	$big = 12345678;
	$page_format = paginate_links( array(
	    'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
	    'format' => '?paged=%#%',
	    'current' => max( 1, get_query_var('paged') ),
	    'total' => $wp_query->max_num_pages,
	    'type'  => 'array'
	) );
	if( is_array($page_format) ) {
		$paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
		echo '<div class="pagination"><div><ul>';
		echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
		foreach ( $page_format as $page ) {
			echo "<li>$page</li>";
		}
		echo '</ul></div></div>';
	}
}
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';


/**
 * Load custom functions file.
 */
require get_template_directory() . '/inc/custom-functions.php';

function excerpt($num) {
        $limit = $num+1;
        $excerpt = explode(' ', get_the_excerpt(), $limit);
        array_pop($excerpt);
        $excerpt = implode(" ",$excerpt)."...";
        echo $excerpt;
    }
	
function business_web_string_limit_words($string, $word_limit){
  $words = explode(' ', $string, ($word_limit + 1));
  if(count($words) > $word_limit)
  array_pop($words);
  return implode(' ', $words);
}	

function business_web_custom_blogpost_pagination( $wp_query ){
	$big = 999999999; // need an unlikely integer
	if ( get_query_var('paged') ) { $pageVar = 'paged'; }
	elseif ( get_query_var('page') ) { $pageVar = 'page'; }
	else { $pageVar = 'paged'; }
	$pagin = paginate_links( array(
		'base' 			=> str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format' 		=> '?'.$pageVar.'=%#%',
		'current' 		=> max( 1, get_query_var($pageVar) ),
		'total' 		=> $wp_query->max_num_pages,
		'prev_text'		=> '&laquo; Prev',
		'next_text' 	=> 'Next &raquo;',
		'type'  => 'array'
	) ); 
	if( is_array($pagin) ) {
		$paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
		echo '<div class="pagination"><div><ul>';
		echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
		foreach ( $pagin as $page ) {
			echo "<li>$page</li>";
		}
		echo '</ul></div></div>';
	} 
}

// get slug by id
function business_web_get_slug_by_id($id) {
	$post_data = get_post($id, ARRAY_A);
	$slug = $post_data['post_name'];
	return $slug; 
}