<?php     

/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */ 

function optionsframework_option_name() {
	// Change this to use your theme slug
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );
	return $themename;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'business-web'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {
	//array of all custom font types.
	$font_types = array( '' => '', 'Arial' => 'Arial',
		'Comic Sans MS' => 'Comic Sans MS',
		'FreeSans' => 'FreeSans',
		'Georgia' => 'Georgia',
		'Lucida Sans Unicode' => 'Lucida Sans Unicode',
		'Palatino Linotype' => 'Palatino Linotype',
		'Symbol' => 'Symbol',
		'Tahoma' => 'Tahoma',
		'Trebuchet MS' => 'Trebuchet MS',
		'Verdana' => 'Verdana',
		'ABeeZee' => 'ABeeZee',
		'Abel' => 'Abel',
		'Abril Fatface' => 'Abril Fatface',
		'Aclonica' => 'Aclonica',
		'Acme' => 'Acme',
		'Actor' => 'Actor',
		'Adamina' => 'Adamina',
		'Advent Pro' => 'Advent Pro',
		'Aguafina Script' => 'Aguafina Script',
		'Akronim' => 'Akronim',
		'Aladin' => 'Aladin',
		'Aldrich' => 'Aldrich',
		'Alegreya' => 'Alegreya',
		'Alegreya SC' => 'Alegreya SC',
		'Alex Brush' => 'Alex Brush',
		'Alfa Slab One' => 'Alfa Slab One',
		'Alice' => 'Alice',
		'Alike' => 'Alike',
		'Alike Angular' => 'Alike Angular',
		'Allan' => 'Allan',
		'Allerta' => 'Allerta',
		'Allerta Stencil' => 'Allerta Stencil',
		'Allura' => 'Allura',
		'Almendra' => 'Almendra',
		'Almendra Display' => 'Almendra Display',
		'Almendra SC' => 'Almendra SC',
		'Amarante' => 'Amarante',
		'Amaranth' => 'Amaranth',
		'Amatic SC' => 'Amatic SC',
		'Amethysta' => 'Amethysta',
		'Anaheim' => 'Anaheim',
		'Andada' => 'Andada',
		'Andika' => 'Andika',
		'Annie Use Your Telescope' => 'Annie Use Your Telescope',
		'Anonymous Pro' => 'Anonymous Pro',
		'Antic' => 'Antic',
		'Antic Didone' => 'Antic Didone',
		'Antic Slab' => 'Antic Slab',
		'Anton' => 'Anton',
		'Arapey' => 'Arapey',
		'Arbutus' => 'Arbutus',
		'Arbutus Slab' => 'Arbutus Slab',
		'Architects Daughter' => 'Architects Daughter',
		'Archivo White' => 'Archivo White',
		'Archivo Narrow' => 'Archivo Narrow',
		'Arimo' => 'Arimo',
		'Arizonia' => 'Arizonia',
		'Armata' => 'Armata',
		'Artifika' => 'Artifika',
		'Arvo' => 'Arvo',
		'Asap' => 'Asap',
		'Asset' => 'Asset',
		'Astloch' => 'Astloch',
		'Asul' => 'Asul',
		'Atomic Age' => 'Atomic Age',
		'Aubrey' => 'Aubrey',
		'Audiowide' => 'Audiowide',
		'Autour One' => 'Autour One',
		'Average' => 'Average',
		'Average Sans' => 'Average Sans',
		'Averia Gruesa Libre' => 'Averia Gruesa Libre',
		'Averia Libre' => 'Averia Libre',
		'Averia Sans Libre' => 'Averia Sans Libre',
		'Averia Serif Libre' => 'Averia Serif Libre',
		'Bad Script' => 'Bad Script',
		'Balthazar' => 'Balthazar',
		'Bangers' => 'Bangers',
		'Basic' => 'Basic',
		'Baumans' => 'Baumans',
		'Belgrano' => 'Belgrano',
		'Belleza' => 'Belleza',
		'BenchNine' => 'BenchNine',
		'Bentham' => 'Bentham',
		'Berkshire Swash' => 'Berkshire Swash',
		'Bevan' => 'Bevan',
		'Bigelow Rules' => 'Bigelow Rules',
		'Bigshot One' => 'Bigshot One',
		'Bilbo' => 'Bilbo',
		'Bilbo Swash Caps' => 'Bilbo Swash Caps',
		'Bitter' => 'Bitter',
		'White Ops One' => 'White Ops One',
		'Bonbon' => 'Bonbon',
		'Boogaloo' => 'Boogaloo',
		'Bowlby One' => 'Bowlby One',
		'Bowlby One SC' => 'Bowlby One SC',
		'Brawler' => 'Brawler',
		'Bree Serif' => 'Bree Serif',
		'Bubblegum Sans' => 'Bubblegum Sans',
		'Bubbler One' => 'Bubbler One',
		'Buda' => 'Buda',
		'Buenard' => 'Buenard',
		'Butcherman' => 'Butcherman',
		'Butcherman Caps' => 'Butcherman Caps',
		'Butterfly Kids' => 'Butterfly Kids',
		'Cabin' => 'Cabin',
		'Cabin Condensed' => 'Cabin Condensed',
		'Cabin Sketch' => 'Cabin Sketch',
		'Cabin' => 'Cabin',
		'Caesar Dressing' => 'Caesar Dressing',
		'Cagliostro' => 'Cagliostro',
		'Calligraffitti' => 'Calligraffitti',
		'Cambo' => 'Cambo',
		'Candal' => 'Candal',
		'Cantarell' => 'Cantarell',
		'Cantata One' => 'Cantata One',
		'Cantora One' => 'Cantora One',
		'Capriola' => 'Capriola',
		'Cardo' => 'Cardo',
		'Carme' => 'Carme',
		'Carrois Gothic' => 'Carrois Gothic',
		'Carrois Gothic SC' => 'Carrois Gothic SC',
		'Carter One' => 'Carter One',
		'Caudex' => 'Caudex',
		'Cedarville Cursive' => 'Cedarville Cursive',
		'Ceviche One' => 'Ceviche One',
		'Changa One' => 'Changa One',
		'Chango' => 'Chango',
		'Chau Philomene One' => 'Chau Philomene One',
		'Chela One' => 'Chela One',
		'Chelsea Market' => 'Chelsea Market',
		'Cherry Cream Soda' => 'Cherry Cream Soda',
		'Cherry Swash' => 'Cherry Swash',
		'Chewy' => 'Chewy',
		'Chicle' => 'Chicle',
		'Chivo' => 'Chivo',
		'Cinzel' => 'Cinzel',
		'Cinzel Decorative' => 'Cinzel Decorative',
		'Clicker Script' => 'Clicker Script',
		'Coda' => 'Coda',
		'Codystar' => 'Codystar',
		'Combo' => 'Combo',
		'Comfortaa' => 'Comfortaa',
		'Coming Soon' => 'Coming Soon',
		'Condiment' => 'Condiment',
		'Contrail One' => 'Contrail One',
		'Convergence' => 'Convergence',
		'Cookie' => 'Cookie',
		'Copse' => 'Copse',
		'Corben' => 'Corben',
		'Courgette' => 'Courgette',
		'Cousine' => 'Cousine',
		'Coustard' => 'Coustard',
		'Covered By Your Grace' => 'Covered By Your Grace',
		'Crafty Girls' => 'Crafty Girls',
		'Creepster' => 'Creepster',
		'Creepster Caps' => 'Creepster Caps',
		'Crete Round' => 'Crete Round',
		'Crimson' => 'Crimson',
		'Croissant One' => 'Croissant One',
		'Crushed' => 'Crushed',
		'Cuprum' => 'Cuprum',
		'Cutive' => 'Cutive',
		'Cutive Mono' => 'Cutive Mono',
		'Damion' => 'Damion',
		'Dancing Script' => 'Dancing Script',
		'Dawning of a New Day' => 'Dawning of a New Day',
		'Days One' => 'Days One',
		'Delius' => 'Delius',
		'Delius Swash Caps' => 'Delius Swash Caps',
		'Delius Unicase' => 'Delius Unicase',
		'Della Respira' => 'Della Respira',
		'Denk One' => 'Denk One',
		'Devonshire' => 'Devonshire',
		'Didact Gothic' => 'Didact Gothic',
		'Diplomata' => 'Diplomata',
		'Diplomata SC' => 'Diplomata SC',
		'Domine' => 'Domine',
		'Donegal One' => 'Donegal One',
		'Doppio One' => 'Doppio One',
		'Dorsa' => 'Dorsa',
		'Dosis' => 'Dosis',
		'Dr Sugiyama' => 'Dr Sugiyama',
		'Droid Sans' => 'Droid Sans',
		'Droid Sans Mono' => 'Droid Sans Mono',
		'Droid Serif' => 'Droid Serif',
		'Duru Sans' => 'Duru Sans',
		'Dynalight' => 'Dynalight',
		'EB Garamond' => 'EB Garamond',
		'Eagle Lake' => 'Eagle Lake',
		'Eater' => 'Eater',
		'Eater Caps' => 'Eater Caps',
		'Economica' => 'Economica',
		'Electrolize' => 'Electrolize',
		'Elsie' => 'Elsie',
		'Elsie Swash Caps' => 'Elsie Swash Caps',
		'Emblema One' => 'Emblema One',
		'Emilys Candy' => 'Emilys Candy',
		'Engagement' => 'Engagement',
		'Englebert' => 'Englebert',
		'Enriqueta' => 'Enriqueta',
		'Erica One' => 'Erica One',
		'Esteban' => 'Esteban',
		'Euphoria Script' => 'Euphoria Script',
		'Ewert' => 'Ewert',
		'Exo' => 'Exo',
		'Expletus Sans' => 'Expletus Sans',
		'Fanwood Text' => 'Fanwood Text',
		'Fascinate' => 'Fascinate',
		'Fascinate Inline' => 'Fascinate Inline',
		'Faster One' => 'Faster One',
		'Federant' => 'Federant',
		'Federo' => 'Federo',
		'Felipa' => 'Felipa',
		'Fenix' => 'Fenix',
		'Finger Paint' => 'Finger Paint',
		'Fjalla One' => 'Fjalla One',
		'Fjord One' => 'Fjord One',
		'Flamenco' => 'Flamenco',
		'Flavors' => 'Flavors',
		'Fondamento' => 'Fondamento',
		'Fontdiner Swanky' => 'Fontdiner Swanky',
		'Forum' => 'Forum',
		'Francois One' => 'Francois One',
		'Freckle Face' => 'Freckle Face',
		'Fredericka the Great' => 'Fredericka the Great',
		'Fredoka One' => 'Fredoka One',
		'Fresca' => 'Fresca',
		'Frijole' => 'Frijole',
		'Fruktur' => 'Fruktur',
		'Fugaz One' => 'Fugaz One',
		'Gafata' => 'Gafata',
		'Galdeano' => 'Galdeano',
		'Galindo' => 'Galindo',
		'Gentium Basic' => 'Gentium Basic',
		'Gentium Book Basic' => 'Gentium Book Basic',
		'Geo' => 'Geo',
		'Geostar' => 'Geostar',
		'Geostar Fill' => 'Geostar Fill',
		'Germania One' => 'Germania One',
		'Gilda Display' => 'Gilda Display',
		'Give You Glory' => 'Give You Glory',
		'Glass Antiqua' => 'Glass Antiqua',
		'Glegoo' => 'Glegoo',
		'Gloria Hallelujah' => 'Gloria Hallelujah',
		'Goblin One' => 'Goblin One',
		'Gochi Hand' => 'Gochi Hand',
		'Gorditas' => 'Gorditas',
		'Goudy Bookletter 1911' => 'Goudy Bookletter 1911',
		'Graduate' => 'Graduate',
		'Grand Hotel' => 'Grand Hotel',
		'Gravitas One' => 'Gravitas One',
		'Great Vibes' => 'Great Vibes',
		'Griffy' => 'Griffy',
		'Gruppo' => 'Gruppo',
		'Gudea' => 'Gudea',
		'Habibi' => 'Habibi',
		'Hammersmith One' => 'Hammersmith One',
		'Hanalei' => 'Hanalei',
		'Hanalei Fill' => 'Hanalei Fill',
		'Handlee' => 'Handlee',
		'Happy Monkey' => 'Happy Monkey',
		'Headland One' => 'Headland One',
		'Henny Penny' => 'Henny Penny',
		'Herr Von Muellerhoff' => 'Herr Von Muellerhoff',
		'Holtwood One SC' => 'Holtwood One SC',
		'Homemade Apple' => 'Homemade Apple',
		'Homenaje' => 'Homenaje',
		'IM Fell' => 'IM Fell',
		'Iceberg' => 'Iceberg',
		'Iceland' => 'Iceland',
		'Imprima' => 'Imprima',
		'Inconsolata' => 'Inconsolata',
		'Inder' => 'Inder',
		'Indie Flower' => 'Indie Flower',
		'Inika' => 'Inika',
		'Irish Growler' => 'Irish Growler',
		'Istok Web' => 'Istok Web',
		'Italiana' => 'Italiana',
		'Italianno' => 'Italianno',
		'Jacques Francois' => 'Jacques Francois',
		'Jacques Francois Shadow' => 'Jacques Francois Shadow',
		'Jim Nightshade' => 'Jim Nightshade',
		'Jockey One' => 'Jockey One',
		'Jolly Lodger' => 'Jolly Lodger',
		'Josefin Sans' => 'Josefin Sans',
		'Josefin Sans' => 'Josefin Sans',
		'Josefin Slab' => 'Josefin Slab',
		'Joti One' => 'Joti One',
		'Judson' => 'Judson',
		'Julee' => 'Julee',
		'Julius Sans One' => 'Julius Sans One',
		'Junge' => 'Junge',
		'Jura' => 'Jura',
		'Just Another Hand' => 'Just Another Hand',
		'Just Me Again Down Here' => 'Just Me Again Down Here',
		'Kameron' => 'Kameron',
		'Karla' => 'Karla',
		'Kaushan Script' => 'Kaushan Script',
		'Kavoon' => 'Kavoon',
		'Keania One' => 'Keania One',
		'Kelly Slab' => 'Kelly Slab',
		'Kenia' => 'Kenia',
		'Kite One' => 'Kite One',
		'Knewave' => 'Knewave',
		'Kotta One' => 'Kotta One',
		'Kranky' => 'Kranky',
		'Kreon' => 'Kreon',
		'Kristi' => 'Kristi',
		'Krona One' => 'Krona One',
		'La Belle Aurore' => 'La Belle Aurore',
		'Lancelot' => 'Lancelot',
		'Lato' => 'Lato',
		'League Script' => 'League Script',
		'Leckerli One' => 'Leckerli One',
		'Ledger' => 'Ledger',
		'Lekton' => 'Lekton',
		'Lemon' => 'Lemon',
		'Libre Baskerville' => 'Libre Baskerville',
		'Life Savers' => 'Life Savers',
		'Lilita One' => 'Lilita One',
		'Limelight' => 'Limelight',
		'Linden Hill' => 'Linden Hill',
		'Lobster' => 'Lobster',
		'Lobster Two' => 'Lobster Two',
		'Londrina Outline' => 'Londrina Outline',
		'Londrina Shadow' => 'Londrina Shadow',
		'Londrina Sketch' => 'Londrina Sketch',
		'Londrina Solid' => 'Londrina Solid',
		'Lora' => 'Lora',
		'Love Ya Like A Sister' => 'Love Ya Like A Sister',
		'Loved by the King' => 'Loved by the King',
		'Lovers Quarrel' => 'Lovers Quarrel',
		'Luckiest Guy' => 'Luckiest Guy',
		'Lusitana' => 'Lusitana',
		'Lustria' => 'Lustria',
		'Macondo' => 'Macondo',
		'Macondo Swash Caps' => 'Macondo Swash Caps',
		'Magra' => 'Magra',
		'Maiden Orange' => 'Maiden Orange',
		'Mako' => 'Mako',
		'Marcellus' => 'Marcellus',
		'Marcellus SC' => 'Marcellus SC',
		'Marck Script' => 'Marck Script',
		'Margarine' => 'Margarine',
		'Marko One' => 'Marko One',
		'Marmelad' => 'Marmelad',
		'Marvel' => 'Marvel',
		'Mate' => 'Mate',
		'Mate SC' => 'Mate SC',
		'Maven Pro' => 'Maven Pro',
		'McLaren' => 'McLaren',
		'Meddon' => 'Meddon',
		'MedievalSharp' => 'MedievalSharp',
		'Medula One' => 'Medula One',
		'Megrim' => 'Megrim',
		'Meie Script' => 'Meie Script',
		'Merienda' => 'Merienda',
		'Merienda One' => 'Merienda One',
		'Merriweather' => 'Merriweather',
		'Metal Mania' => 'Metal Mania',
		'Metamorphous' => 'Metamorphous',
		'Metrophobic' => 'Metrophobic',
		'Michroma' => 'Michroma',
		'Milonga' => 'Milonga',
		'Miltonian' => 'Miltonian',
		'Miltonian Tattoo' => 'Miltonian Tattoo',
		'Miniver' => 'Miniver',
		'Miss Fajardose' => 'Miss Fajardose',
		'Miss Saint Delafield' => 'Miss Saint Delafield',
		'Modern Antiqua' => 'Modern Antiqua',
		'Molengo' => 'Molengo',
		'Molle' => 'Molle',
		'Monda' => 'Monda',
		'Monofett' => 'Monofett',
		'Monoton' => 'Monoton',
		'Monsieur La Doulaise' => 'Monsieur La Doulaise',
		'Montaga' => 'Montaga',
		'Montez' => 'Montez',
		'Montserrat' => 'Montserrat',
		'Montserrat Alternates' => 'Montserrat Alternates',
		'Montserrat Subrayada' => 'Montserrat Subrayada',
		'Mountains of Christmas' => 'Mountains of Christmas',
		'Mouse Memoirs' => 'Mouse Memoirs',
		'Mr Bedford' => 'Mr Bedford',
		'Mr Bedfort' => 'Mr Bedfort',
		'Mr Dafoe' => 'Mr Dafoe',
		'Mr De Haviland' => 'Mr De Haviland',
		'Mrs Saint Delafield' => 'Mrs Saint Delafield',
		'Mrs Sheppards' => 'Mrs Sheppards',
		'Muli' => 'Muli',
		'Mystery Quest' => 'Mystery Quest',
		'Neucha' => 'Neucha',
		'Neuton' => 'Neuton',
		'New Rocker' => 'New Rocker',
		'News Cycle' => 'News Cycle',
		'Niconne' => 'Niconne',
		'Nixie One' => 'Nixie One',
		'Nobile' => 'Nobile',
		'Norican' => 'Norican',
		'Nosifer' => 'Nosifer',
		'Nosifer Caps' => 'Nosifer Caps',
		'Noticia Text' => 'Noticia Text',
		'Nova Round' => 'Nova Round',
		'Numans' => 'Numans',
		'Nunito' => 'Nunito',
		'Offside' => 'Offside',
		'Oldenburg' => 'Oldenburg',
		'Oleo Script' => 'Oleo Script',
		'Oleo Script Swash Caps' => 'Oleo Script Swash Caps',
		'Open Sans' => 'Open Sans',
		'Open Sans Condensed' => 'Open Sans Condensed',
		'Oranienbaum' => 'Oranienbaum',
		'Orbitron' => 'Orbitron',
		'Oregano' => 'Oregano',
		'Orienta' => 'Orienta',
		'Original Surfer' => 'Original Surfer',
		'Oswald' => 'Oswald',
		'Over the Rainbow' => 'Over the Rainbow',
		'Overlock' => 'Overlock',
		'Overlock SC' => 'Overlock SC',
		'Ovo' => 'Ovo',
		'Oxygen' => 'Oxygen',
		'Oxygen Mono' => 'Oxygen Mono',
		'PT Mono' => 'PT Mono',
		'PT Sans' => 'PT Sans',
		'PT Sans Narrow' => 'PT Sans Narrow',
		'PT Serif' => 'PT Serif',
		'PT Serif Caption' => 'PT Serif Caption',
		'Pacifico' => 'Pacifico',
		'Paprika' => 'Paprika',
		'Parisienne' => 'Parisienne',
		'Passero One' => 'Passero One',
		'Passion One' => 'Passion One',
		'Patrick Hand' => 'Patrick Hand',
		'Patua One' => 'Patua One',
		'Paytone One' => 'Paytone One',
		'Peralta' => 'Peralta',
		'Permanent Marker' => 'Permanent Marker',
		'Petit Formal Script' => 'Petit Formal Script',
		'Petrona' => 'Petrona',
		'Philosopher' => 'Philosopher',
		'Piedra' => 'Piedra',
		'Pinyon Script' => 'Pinyon Script',
		'Pirata One' => 'Pirata One',
		'Plaster' => 'Plaster',
		'Play' => 'Play',
		'Playball' => 'Playball',
		'Playfair Display' => 'Playfair Display',
		'Playfair Display SC' => 'Playfair Display SC',
		'Podkova' => 'Podkova',
		'Poiret One' => 'Poiret One',
		'Poller One' => 'Poller One',
		'Poly' => 'Poly',
		'Pompiere' => 'Pompiere',
		'Pontano Sans' => 'Pontano Sans',
		'Port Lligat Sans' => 'Port Lligat Sans',
		'Port Lligat Slab' => 'Port Lligat Slab',
		'Prata' => 'Prata',
		'Press Start 2P' => 'Press Start 2P',
		'Princess Sofia' => 'Princess Sofia',
		'Prociono' => 'Prociono',
		'Prosto One' => 'Prosto One',
		'Puritan' => 'Puritan',
		'Purple Purse' => 'Purple Purse',
		'Quando' => 'Quando',
		'Quantico' => 'Quantico',
		'Quattrocento' => 'Quattrocento',
		'Quattrocento Sans' => 'Quattrocento Sans',
		'Questrial' => 'Questrial',
		'Quicksand' => 'Quicksand',
		'Quintessential' => 'Quintessential',
		'Qwigley' => 'Qwigley',
		'Racing Sans One' => 'Racing Sans One',
		'Radley' => 'Radley',
		'Raleway Dots' => 'Raleway Dots',
		'Raleway' => 'Raleway',
		'Rambla' => 'Rambla',
		'Rammetto One' => 'Rammetto One',
		'Ranchers' => 'Ranchers',
		'Rancho' => 'Rancho',
		'Rationale' => 'Rationale',
		'Redressed' => 'Redressed',
		'Reenie Beanie' => 'Reenie Beanie',
		'Revalia' => 'Revalia',
		'Ribeye' => 'Ribeye',
		'Ribeye Marrow' => 'Ribeye Marrow',
		'Righteous' => 'Righteous',
		'Risque' => 'Risque',
		'Roboto' => 'Roboto',
		'Roboto Condensed' => 'Roboto Condensed',
		'Roboto Condensed Light' => 'Roboto Condensed Light',
		'Rochester' => 'Rochester',
		'Rock Salt' => 'Rock Salt',
		'Rokkitt' => 'Rokkitt',
		'Romanesco' => 'Romanesco',
		'Ropa Sans' => 'Ropa Sans',
		'Rosario' => 'Rosario',
		'Rosarivo' => 'Rosarivo',
		'Rouge Script' => 'Rouge Script',
		'Ruda' => 'Ruda',
		'Rufina' => 'Rufina',
		'Ruge Boogie' => 'Ruge Boogie',
		'Ruluko' => 'Ruluko',
		'Rum Raisin' => 'Rum Raisin',
		'Ruslan Display' => 'Ruslan Display',
		'Russo One' => 'Russo One',
		'Ruthie' => 'Ruthie',
		'Rye' => 'Rye',
		'Sacramento' => 'Sacramento',
		'Sail' => 'Sail',
		'Salsa' => 'Salsa',
		'Sanchez' => 'Sanchez',
		'Sancreek' => 'Sancreek',
		'Sansita One' => 'Sansita One',
		'Sarina' => 'Sarina',
		'Satisfy' => 'Satisfy',
		'Scada' => 'Scada',
		'Schoolbell' => 'Schoolbell',
		'Seaweed Script' => 'Seaweed Script',
		'Sevillana' => 'Sevillana',
		'Seymour One' => 'Seymour One',
		'Shadows Into Light' => 'Shadows Into Light',
		'Shadows Into Light Two' => 'Shadows Into Light Two',
		'Shanti' => 'Shanti',
		'Share' => 'Share',
		'Share Tech' => 'Share Tech',
		'Share Tech Mono' => 'Share Tech Mono',
		'Shojumaru' => 'Shojumaru',
		'Short Stack' => 'Short Stack',
		'Sigmar One' => 'Sigmar One',
		'Signika' => 'Signika',
		'Signika Negative' => 'Signika Negative',
		'Simonetta' => 'Simonetta',
		'Sirin Stencil' => 'Sirin Stencil',
		'Six Caps' => 'Six Caps',
		'Skranji' => 'Skranji',
		'Slackey' => 'Slackey',
		'Smokum' => 'Smokum',
		'Smythe' => 'Smythe',
		'Sniglet' => 'Sniglet',
		'Snippet' => 'Snippet',
		'Snowburst One' => 'Snowburst One',
		'Sofadi One' => 'Sofadi One',
		'Sofia' => 'Sofia',
		'Sonsie One' => 'Sonsie One',
		'Sorts Mill Goudy' => 'Sorts Mill Goudy',
		'Sorts Mill Goudy' => 'Sorts Mill Goudy',
		'Source Code Pro' => 'Source Code Pro',
		'Source Sans Pro' => 'Source Sans Pro',
		'Special I am one' => 'Special I am one',
		'Spicy Rice' => 'Spicy Rice',
		'Spinnaker' => 'Spinnaker',
		'Spirax' => 'Spirax',
		'Squada One' => 'Squada One',
		'Stalemate' => 'Stalemate',
		'Stalinist One' => 'Stalinist One',
		'Stardos Stencil' => 'Stardos Stencil',
		'Stint Ultra Condensed' => 'Stint Ultra Condensed',
		'Stint Ultra Expanded' => 'Stint Ultra Expanded',
		'Stoke' => 'Stoke',
		'Stoke' => 'Stoke',
		'Strait' => 'Strait',
		'Sue Ellen Francisco' => 'Sue Ellen Francisco',
		'Sunshiney' => 'Sunshiney',
		'Supermercado One' => 'Supermercado One',
		'Swanky and Moo Moo' => 'Swanky and Moo Moo',
		'Syncopate' => 'Syncopate',
		'Tangerine' => 'Tangerine',
		'Telex' => 'Telex',
		'Tenor Sans' => 'Tenor Sans',
		'Terminal Dosis' => 'Terminal Dosis',
		'Terminal Dosis Light' => 'Terminal Dosis Light',
		'Text Me One' => 'Text Me One',
		'The Girl Next Door' => 'The Girl Next Door',
		'Tienne' => 'Tienne',
		'Tinos' => 'Tinos',
		'Titan One' => 'Titan One',
		'Titillium Web' => 'Titillium Web',
		'Trade Winds' => 'Trade Winds',
		'Trocchi' => 'Trocchi',
		'Trochut' => 'Trochut',
		'Trykker' => 'Trykker',
		'Tulpen One' => 'Tulpen One',
		'Ubuntu' => 'Ubuntu',
		'Ubuntu Condensed' => 'Ubuntu Condensed',
		'Ubuntu Mono' => 'Ubuntu Mono',
		'Ultra' => 'Ultra',
		'Uncial Antiqua' => 'Uncial Antiqua',
		'Underdog' => 'Underdog',
		'Unica One' => 'Unica One',
		'UnifrakturCook' => 'UnifrakturCook',
		'UnifrakturMaguntia' => 'UnifrakturMaguntia',
		'Unkempt' => 'Unkempt',
		'Unlock' => 'Unlock',
		'Unna' => 'Unna',
		'VT323' => 'VT323',
		'Vampiro One' => 'Vampiro One',
		'Varela' => 'Varela',
		'Varela Round' => 'Varela Round',
		'Vast Shadow' => 'Vast Shadow',
		'Vibur' => 'Vibur',
		'Vidaloka' => 'Vidaloka',
		'Viga' => 'Viga',
		'Voces' => 'Voces',
		'Volkhov' => 'Volkhov',
		'Vollkorn' => 'Vollkorn',
		'Voltaire' => 'Voltaire',
		'Waiting for the Sunrise' => 'Waiting for the Sunrise',
		'Wallpoet' => 'Wallpoet',
		'Walter Turncoat' => 'Walter Turncoat',
		'Warnes' => 'Warnes',
		'Wellfleet' => 'Wellfleet',
		'Wendy One' => 'Wendy One',
		'Wire One' => 'Wire One',
		'Yanone Kaffeesatz' => 'Yanone Kaffeesatz',
		'Yellowtail' => 'Yellowtail',
		'Yeseva One' => 'Yeseva One',
		'Yesteryear' => 'Yesteryear',
		'Zeyada' => 'Zeyada'
	);

	//array of all font sizes.
	$font_sizes = array( 
		'10px' => '10px',
		'11px' => '11px',
	);
	
	$options = array();
	$imagepath =  get_template_directory_uri() . '/images/';

	for($n=12;$n<=200;$n+=1){
		$font_sizes[$n.'px'] = $n.'px';
	}	
	
	// Pull all the pages into an array
	 $options_pages = array();
	 $options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	 $options_pages[''] = 'Select a page:';
	 foreach ($options_pages_obj as $page) {
	  $options_pages[$page->ID] = $page->post_title;
	 }

	// array of section content.
	$section_text = array(
	
		1 => array(
			'section_title'	=> '',
			'menutitle'		=> 'aboutsection',
			'bgcolor' 		=> '#e8e8e8',
			'bgimage'		=> '',
			'class'			=> 'about-wrap',
			'content'		=> '[column_content type="one_half"]<img src="'.get_template_directory_uri().'/images/thumb2.png" alt="" />[/column_content]

[column_content type="one_half_last"]
<h2><i style="color: #f2c008;" class="fa fa-star"></i> Our Theme Features</h2>
         <ul>
<li><i class="fa fa-check"></i> Responsive &amp; Mobile Optimized Themes</li>
<li><i class="fa fa-check"></i> Highly Customizable</li>
<li><i class="fa fa-check"></i> User Friendly Theme Options: User can modified easily.</li>
<li><i class="fa fa-check"></i> Multilingual Ready Themes</li>
<li><i class="fa fa-check"></i> Nextgen Gallery compatible</li>
<li><i class="fa fa-check"></i> WooCommerce Ready</li>
<li><i class="fa fa-check"></i> Header and Footer Widgetise</li>
</ul>[/column_content]'
		),			
		
		2 => array(
			'section_title'	=> '',
			'menutitle'		=> 'wrapsecond',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> 'services-wrap',
			'content'		=> '[column_content type="one_fourth"]<a href="#"><i class="fa fa-users"></i><h4>Qualified Team</h4></a><p>Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. </p><a class="rdmore" href="#">Read More &raquo;</a>[/column_content]

[column_content type="one_fourth"]<a href="#"><i class="fa fa-gears"></i><h4>Superior Support</h4></a> <p>Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus.</p><a class="rdmore" href="#">Read More &raquo;</a>[/column_content]

[column_content type="one_fourth"]<a href="#"><i class="fa fa-desktop"></i><h4>The Best Design</h4></a> <p>Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus.</p><a class="rdmore" href="#">Read More &raquo;</a>[/column_content]

[column_content type="one_fourth_last"]<a href="#"><i class="fa fa-cloud-download"></i><h4>Free Theme Download</h4></a> <p>Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. </p><a class="rdmore" href="#">Read More &raquo;</a>[/column_content]',
		),
		
		3 => array(
			'section_title'	=> 'Our Experts Team',
			'menutitle'		=> 'ourteam',
			'bgcolor' 		=> '',
			'bgimage'		=> get_template_directory_uri().'/images/teambg.jpg',
			'class'			=> 'team-wrap',
			'content'		=> '[ourteam show="4"] '
		),		
		
		4 => array(
			'section_title'	=> 'Recents Posts',
			'menutitle'		=> 'latestposts',
			'bgcolor' 		=> '#f8f8f8',
			'bgimage'		=> '',
			'class'			=> 'recentpost-wrap',
			'content'		=> '[recent-posts show="4"]'
		),		
		
		5 => array(
			'section_title'	=> '',
			'menutitle'		=> 'testimonialsarea',
			'bgcolor' 		=> '#5095ce',
			'bgimage'		=> '',
			'class'			=> 'testimonials-wrap',
			'content'		=> '[column_content type="one_half"]<h2>Success Story</h2>[testimonials][/column_content][column_content type="one_half_last"]<img src="'.get_template_directory_uri().'/images/tmbg.jpg" alt="" />[/column_content]',
		
		),
		
		6 => array(
			'section_title'	=> 'Recent Projects',
			'menutitle'		=> 'ourgallery',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> 'gallerywrap',
			'content'		=> '[photogallery filter="true"]'
		),	
		
		7 => array(
			'section_title'	=> 'Tab & Toggle Features',
			'menutitle'		=> 'tabtoggle',
			'bgcolor' 		=> '#f8f8f8',
			'bgimage'		=> get_template_directory_uri().'/images/tabbanar.jpg',
			'class'			=> 'tabwrap',
			'content'		=> '[column_content type="one_half"][accordion]
	[accordion_content title="Accordion Title 1"]
		m ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus.
	[/accordion_content]
	[accordion_content title="Accordion Title 2"]
		m ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus.
	[/accordion_content]
	[accordion_content title="Accordion Title 3"]
		m ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus.
	[/accordion_content]
[/accordion]	
[/column_content]

[column_content type="one_half_last"][tabs]
	[tab title="Tab Title 1"]<img class="tabimg" src="'.get_template_directory_uri().'/images/thumb2.png" alt="" />Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus.
	
	Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus.
	[/tab]
	[tab title="Tab Title 2"]
		Dolor sit amet, consectetur adipiscinr sed gravida tortor consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus sed gravida tortor consectetur adipiscinr sed gravida tortor,. 
		
		Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus.
	[/tab]
	[tab title="Tab Title 3"]
		Dummy ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus.
		
		Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus consectetur adipiscinr sed gravida tortor sed gravida tortor consectetur adipiscinr sed gravida tortor,.
	[/tab]
[/tabs]
[/column_content]'
		),
		
		8 => array(
			'section_title'	=> 'Our Clients',
			'menutitle'		=> 'clientarea',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> 'clientwrap',
			'content'		=> '[client_lists][client image="'.get_template_directory_uri().'/images/logo1.jpg" link="#"][client image="'.get_template_directory_uri().'/images/logo2.jpg" link="#"][client image="'.get_template_directory_uri().'/images/logo3.jpg" link="#"][client image="'.get_template_directory_uri().'/images/logo4.jpg" link="#"][client image="'.get_template_directory_uri().'/images/logo5.jpg" link="#"][/client_lists]'
		),

	);

	$options = array();

	//Basic Settings
	$options[] = array(
		'name' => __('Basic Settings', 'business-web'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Logo', 'business-web'),
		'desc' => __('Upload your main logo here', 'business-web'),
		'id' => 'logo',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
		
	$options[] = array(		
		'desc' => __('manage your custom logo height', 'business-web'),
		'id' => 'logoheight',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(	
		'name' => __('Site title & Description', 'business-web'),		
		'desc'	=> __('Check To hide site title and description', 'business-web'),
		'id'	=> 'hide_titledesc',
		'type'	=> 'checkbox',
		'std'	=> '');	
		
	$options[] = array(	
		'name' => __('Layout Option', 'business-web'),		
		'desc'	=> __('Check To View Box Layout ', 'business-web'),
		'id'	=> 'boxlayout',
		'type'	=> 'checkbox',
		'std'	=> '');		
	
	$options[] = array(
		'name' => __('Custom CSS', 'business-web'),
		'desc' => __('Some Custom Styling for your site. Place any css codes here instead of the style.css file.', 'business-web'),
		'id' => 'style2',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Header Top Info', 'business-web'),
		'desc' => __('Edit header info from here. NOTE: Icon name should be in lowercase without space.(exa.phone) More social icons can be found at: http://fortawesome.github.io/Font-Awesome/icons/', 'business-web'),
		'id' => 'headerinfo',
		'std' => '<i class="fa fa-phone"></i> <span class="phno">+11 123 456 7890</span> <i class="fa fa-envelope"></i>demomail@gmail.com ',
		'type' => 'textarea');	
		
	$options[] = array(
		'name' => __('Header Top Social Icons', 'business-web'),
		'desc' => __('Edit select social icons for header top', 'business-web'),
		'id' => 'headersocial',
		'std' => ' [social_area]<span>Follow us:</span> [social icon="facebook" link="#"] [social icon="twitter" link="#"] [social icon="google-plus" link="#"] [social icon="linkedin" link="#"][/social_area]',
		'type' => 'textarea');	
		
		
	$options[] = array(
		'name' => __('Disable Header top Strip', 'business-web'),
		'desc' => __('Check to disable header top contact info and social icons', 'business-web'),
		'id' => 'headtopstrip',
		'std' => '',
		'type' => 'checkbox');		
		
	$options[] = array(
		'name' => __('Sticky Header', 'business-web'),
		'desc' => __('Uncheck this to enable sticky header on scroll', 'business-web'),
		'id' => 'headstick',
		'std' => 'checked',
		'type' => 'checkbox');
		
	$options[] = array(
		'name' => __('Disable Animation', 'business-web'),
		'desc' => __('Check this to disable animation on scroll', 'business-web'),
		'id' => 'scrollanimation',
		'std' => '',
		'type' => 'checkbox');		
		
	// font family start 		
	$options[] = array(
		'name' => __('Font Faces', 'business-web'),
		'desc' => __('Select font for the body text', 'business-web'),
		'id' => 'bodyfontface',
		'type' => 'select',
		'std' => 'PT Sans',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the textual logo', 'business-web'),
		'id' => 'logofontface',
		'type' => 'select',
		'std' => 'Raleway',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the navigation text', 'business-web'),
		'id' => 'navfontface',
		'type' => 'select',
		'std' => 'Raleway',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for heading text. eg: H1, H2, H3, H4, H5, H6', 'business-web'),
		'id' => 'headfontface',
		'type' => 'select',
		'std' => 'Raleway',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font family for header top bar', 'business-web'),
		'id' => 'hdrtopfontface',
		'type' => 'select',
		'std' => 'PT Sans',
		'options' => $font_types );	
		
	// font sizes start	
	$options[] = array(
		'name' => __('Font Sizes', 'business-web'),
		'desc' => __('Select font size for body text', 'business-web'),
		'id' => 'bodyfontsize',
		'type' => 'select',
		'std' => '13px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for textual logo', 'business-web'),
		'id' => 'logofontsize',
		'type' => 'select',
		'std' => '36px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for navigation', 'business-web'),
		'id' => 'navfontsize',
		'type' => 'select',
		'std' => '15px',
		'options' => $font_sizes );	
		
	$options[] = array(
		'desc' => __('Select font size for section title', 'business-web'),
		'id' => 'sectitlesize',
		'type' => 'select',
		'std' => '30px',
		'options' => $font_sizes );
	
		
	$options[] = array(
		'desc' => __('Select font size for footer title', 'business-web'),
		'id' => 'ftfontsize',
		'type' => 'select',
		'std' => '18px',
		'options' => $font_sizes );	
		
	$options[] = array(
		'desc' => __('Select font size for header top bar', 'business-web'),
		'id' => 'hdrtopfontsize',
		'type' => 'select',
		'std' => '13px',
		'options' => $font_sizes );	
		
		
	$options[] = array(	
		'name' => __('Header Menu Italic Text', 'business-web'),	
		'desc' => __('Select font style for header menu italic text', 'business-web'),
		'id' => 'menufontstyle',
		'std' => 'italic',
		'type' => 'select',		
		'options' => array('italic' => 'italic','normal' => 'normal'));
			

	// font colors start

	$options[] = array(
		'name' => __('Font Colors', 'business-web'),
		'desc' => __('Select font color for the body text', 'business-web'),
		'id' => 'bodyfontcolor',
		'std' => '#364558',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for textual logo', 'business-web'),
		'id' => 'logofontcolor',
		'std' => '#5095ce',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for section title', 'business-web'),
		'id' => 'sectitlecolor',
		'std' => '#484f5e',
		'type' => 'color');			
	

	$options[] = array(
		'desc' => __('Select font color for navigation', 'business-web'),
		'id' => 'navfontcolor',
		'std' => '#666666',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for navigation hover', 'business-web'),
		'id' => 'navhovercolor',
		'std' => '#5095CE',
		'type' => 'color');
	
	$options[] = array(
		'desc' => __('Select font color for four boxes title first section', 'business-web'),
		'id' => 'pagebxttlfontcolor',
		'std' => '#404040',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for four boxes title first section', 'business-web'),
		'id' => 'pagebxttlfontcolorhv',
		'std' => '#5095ce',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for four boxes read more button first section', 'business-web'),
		'id' => 'pagebxbtnfontcolor',
		'std' => '#404040',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select font hover color for four boxes read more button first section', 'business-web'),
		'id' => 'pagebxbtnfontcolorhv',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font active color for recent project( photo gallery ) filter', 'business-web'),
		'id' => 'galleryfilteractivecolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for widget title', 'business-web'),
		'id' => 'wdgttitleccolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer title', 'business-web'),
		'id' => 'foottitlecolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer', 'business-web'),
		'id' => 'footdesccolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer menu ', 'business-web'),
		'id' => 'footermenucolor',
		'std' => '#ffffff',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select hover/active font color for footer menu ', 'business-web'),
		'id' => 'footermenucurrent',
		'std' => '#5095CE',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for footer left text (copyright)', 'business-web'),
		'id' => 'copycolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer right text (design by)', 'business-web'),
		'id' => 'designcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for links / anchor tags', 'business-web'),
		'id' => 'linkcolor',
		'std' => '#5095CE',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for links / anchor tags on hover', 'business-web'),
		'id' => 'linkhovercolor',
		'std' => '#5095CE',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for sidebar li a', 'business-web'),
		'id' => 'sidebarfontcolor',
		'std' => '#3b3b3b',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for sidebar li a', 'business-web'),
		'id' => 'sidebarfonthvcolor',
		'std' => '#5095CE',
		'type' => 'color');			
			
	$options[] = array(
		'desc' => __('Select font color for Testimonials title', 'business-web'),
		'id' => 'tmn_titlefontcolor',
		'std' => '#3c3b3b',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer links', 'business-web'),
		'id' => 'copylinks',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for footer links', 'business-web'),
		'id' => 'copylinkshover',
		'std' => '#5095CE',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select font color for social icons', 'business-web'),
		'id' => 'socialfontcolor',
		'std' => '#c9c8c8',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select border hover color for social icons', 'business-web'),
		'id' => 'socialfonthvcolor',
		'std' => '#5095CE',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select title color for footer posts', 'business-web'),
		'id' => 'footerpoststitle',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select title hover color for footer posts', 'business-web'),
		'id' => 'footerpoststitlehv',
		'std' => '#5095CE',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for our team title', 'business-web'),
		'id' => 'teamtitlecolor',
		'std' => '#666666',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for our team title', 'business-web'),
		'id' => 'teamtitlehovercolor',
		'std' => '#5095CE',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select color for our team social icon', 'business-web'),
		'id' => 'teamsicolor',
		'std' => '#cccccc',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select hover color for our team social icon', 'business-web'),
		'id' => 'teamsicolorhv',
		'std' => '#5095CE',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select font color for header top bar', 'business-web'),
		'id' => 'hdrtopfontcolor',
		'std' => '#413930',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select phone icon color for header top', 'business-web'),
		'id' => 'phoneiconcolor',
		'std' => '#5095CE',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for three column services icon', 'business-web'),
		'id' => 'srvciconfc',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for three column services icon', 'business-web'),
		'id' => 'srvciconfchv',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select read more link color for three column services box', 'business-web'),
		'id' => 'srvclinkcolor',
		'std' => '#78797c',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select link hover color for three column services box', 'business-web'),
		'id' => 'srvclinkcolorhv',
		'std' => '#5095CE',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select title hover color for three column services box', 'business-web'),
		'id' => 'titlecolorhv',
		'std' => '#5095CE',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for our team paragraph', 'business-web'),
		'id' => 'teamparacolor',
		'std' => '#666666',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for success story section', 'business-web'),
		'id' => 'tsmlfontcolor',
		'std' => '#ffffff',
		'type' => 'color');																
	
	// Background start		
	$options[] = array(	
		'name' => __('Background Colors', 'business-web'),	
		'desc' => __('Select background color for header', 'business-web'),
		'id' => 'headerbg',
		'std' => '#ffffff',
		'type' => 'color');	
	
		
	$options[] = array(
		'desc' => __('Select background color for footer', 'business-web'),
		'id' => 'footerbgcolor',
		'std' => '#364558',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for copyright section', 'business-web'),
		'id' => 'copybgcolor',
		'std' => '#28374a',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for sidebar widget', 'business-web'),
		'id' => 'sidebarbgcolor',
		'std' => '#f9f9f9',
		'type' => 'color');	
		
	$options[] = array(	
		'desc' => __('Select background color for header top bar', 'business-web'),
		'id' => 'hdrtopbgcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for toggle menu', 'business-web'),
		'id' => 'togglemenu',
		'std' => '#5095CE',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color default search form', 'business-web'),
		'id' => 'searchbgcolor',
		'std' => '#5095CE',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for three column services icon', 'business-web'),
		'id' => 'srvciconbg',
		'std' => '#A8B1B8',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background hover color for three column services icon', 'business-web'),
		'id' => 'srvciconbghv',
		'std' => '#5095CE',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for testimonials pagination', 'business-web'),
		'id' => 'tmnpagerbg',
		'std' => '#464d51',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background hover color for testimonials pagination', 'business-web'),
		'id' => 'tmnpagerbghv',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for sidebat widget title', 'business-web'),
		'id' => 'widgettitlebgcolor',
		'std' => '#5095CE',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for toggle menu on responsive view', 'business-web'),
		'id' => 'tgmenuresponsivebg',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for recent project( photo gallery ) filter tab', 'business-web'),
		'id' => 'galleryfilterbg',
		'std' => '#ffffff',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select background active color for recent project( photo gallery ) filter tab', 'business-web'),
		'id' => 'galleryfilterbghv',
		'std' => '#5095ce',
		'type' => 'color');																			
		
	$options[] = array(
		'desc' => __('Select background hover color for four boxes read more button first section', 'business-web'),
		'id' => 'pagebxbtnbghv',
		'std' => '#5095ce',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background active color for accordian title', 'business-web'),
		'id' => 'acctitlebgcoloractive',
		'std' => '#5095ce',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background active color for tab title', 'business-web'),
		'id' => 'tabtitlebgcoloractive',
		'std' => '#5095ce',
		'type' => 'color');				
		
	// Border colors		
	$options[] = array(	
		'name' => __('Border Colors', 'business-web'),				
		'desc' => __('Select top border color for our team social icon', 'business-web'),
		'id' => 'teamsiconborder',
		'std' => '#e6e6e6',
		'type' => 'color');
		
	$options[] = array(			
		'desc' => __('Select border color for header top', 'business-web'),
		'id' => 'headerborder',
		'std' => '#5095CE',
		'type' => 'color');			
		
	$options[] = array(			
		'desc' => __('Select border color for iframe', 'business-web'),
		'id' => 'iframeborder',
		'std' => '#e5e5e4',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for sidebar li a', 'business-web'),
		'id' => 'sidebarliaborder',
		'std' => '#d0cfcf',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for read more button', 'business-web'),
		'id' => 'readmorebutton',
		'std' => '#454545',
		'type' => 'color');	
	
	$options[] = array(			
		'desc' => __('Select border hover color for read more button', 'business-web'),
		'id' => 'readmorebuttonhv',
		'std' => '#5095CE',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border bottom color for section', 'business-web'),
		'id' => 'secborderbottom',
		'std' => '#eaeaea',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for footer title', 'business-web'),
		'id' => 'foottitleborder',
		'std' => '#46576C',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select border color for recent project( photo gallery ) filter tab', 'business-web'),
		'id' => 'galleryfilterborder',
		'std' => '#e5e5e5',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select border color for four boxes read more button first section', 'business-web'),
		'id' => 'pagebxmorebtnborder',
		'std' => '#404040',
		'type' => 'color');			
		
	// Default Buttons		
	$options[] = array(
		'name' => __('Button Colors', 'business-web'),		
		'desc' => __('Select background color for button', 'business-web'),
		'id' => 'btnbgcolor',
		'std' => '#5095CE',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select hover background color for button', 'business-web'),
		'id' => 'btnbghvcolor',
		'std' => '#037ee5',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select font color button', 'business-web'),
		'id' => 'btntxtcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color button on hover', 'business-web'),
		'id' => 'btntxthvcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		

		
	// Slider Caption colors	
	$options[] = array(	
		'name' => __('Slider Caption Colors', 'business-web'),			
		'desc' => __('Select font color for slider title', 'business-web'),
		'id' => 'slidetitlecolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select font color for slider description', 'business-web'),
		'id' => 'slidedesccolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select font color for slider button', 'business-web'),
		'id' => 'slidebtncolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select font hover color for slider button', 'business-web'),
		'id' => 'slidebtncolorhv',
		'std' => '#194162',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font size for slider title', 'business-web'),
		'id' => 'slidetitlefontsize',
		'type' => 'select',
		'std' => '36px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for slider description', 'business-web'),
		'id' => 'slidedescfontsize',
		'type' => 'select',
		'std' => '13px',
		'options' => $font_sizes );
		
		
	// Slider controls colors		
	$options[] = array(
		'name' => __('Slider controls Colors', 'business-web'),
		'desc' => __('Select background color for slider pager', 'business-web'),
		'id' => 'sldpagebg',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for slider pager active', 'business-web'),
		'id' => 'sldpagehvbg',
		'std' => '#5095CE',
		'type' => 'color');	
		
	$options[] = array(
		'name' => __('Blog Single Layout', 'business-web'),
		'desc' => __('Select layout. eg:Boxed, Wide', 'business-web'),
		'id' => 'singlelayout',
		'type' => 'select',
		'std' => 'singleright',
		'options' => array('singleright'=>'Blog Single Right Sidebar', 'singleleft'=>'Blog Single Left Sidebar', 'sitefull'=>'Blog Single Full Width', 'nosidebar'=>'Blog Single No Sidebar') );	
		
	$options[] = array(
		'name' => __('Social Icon Style', 'business-web'),
		'desc' => __('Select Style. eg:circle, square', 'business-web'),
		'id' => 'socialstyle',		
		'std' => '50',
		'type' => 'select',
		'options' => array('50'=>'Social icons Style in Circle', '0'=>'Social icons Style in Square') );	
		
	$options[] = array(	
		'name' => __('Testimonials Rotating Speed', 'business-web'),	
		'desc' => __('manage testimonials rotating speed.', 'business-web'),
		'id' => 'testimonialsrotatingspeed',
		'std' => '8000',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('True/False Auto play Testimonials.','business-web'),
		'id' => 'testimonialsautoplay',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'True', 'false'=>'False'));	
		
	$options[] = array(	
		'name' => __('Custom Excerpt Length', 'business-web'),	
		'desc' => __('manage excerpt length for testimonials', 'business-web'),
		'id' => 'testimonialexcerpt',
		'std' => '50',
		'type' => 'text');
		
	$options[] = array(			
		'desc' => __('manage excerpt length for our team member', 'business-web'),
		'id' => 'teammemberexcerpt',
		'std' => '22',
		'type' => 'text');
		
	$options[] = array(			
		'desc' => __('manage excerpt length for recent posts', 'business-web'),
		'id' => 'recentpostexcerpt',
		'std' => '20',
		'type' => 'text');	
		
	$options[] = array(			
		'desc' => __('manage excerpt length for footer recent posts', 'business-web'),
		'id' => 'footerpostlength',
		'std' => '10',
		'type' => 'text');	
		
	$options[] = array(	
		'name' => __('Custom Read more Text', 'business-web'),	
		'desc' => __('change read more button text for home page recent posts', 'business-web'),
		'id' => 'recentpostreadmoretext',
		'std' => 'Read more &raquo;',
		'type' => 'text');	
		
	$options[] = array(			
		'desc' => __('Change All Butoon text for recent project ', 'business-web'),
		'id' => 'recentprojectalltext',
		'std' => 'All',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('Change menu text on responsive view', 'business-web'),
		'id' => 'menuwordchange',
		'std' => 'Menu',
		'type' => 'text');					
				

	//Layout Settings
	$options[] = array(
		'name' => __('Sections', 'business-web'),
		'type' => 'heading');
		
		
	$options[] = array(	
		'desc'	=> __('first Services box for frontpage section','business-web'),
		'id' 	=> 'box1',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for first box.', 'business-web'),
		'id' => 'boximg1',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Second Services box for frontpage section','business-web'),
		'id' 	=> 'box2',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for second box.', 'business-web'),
		'id' => 'boximg2',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Third Services box for frontpage section','business-web'),
		'id' 	=> 'box3',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for third box.', 'business-web'),
		'id' => 'boximg3',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Fourth Services box for frontpage section','business-web'),
		'id' 	=> 'box4',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for fourth box.', 'business-web'),
		'id' => 'boximg4',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
		
	$options[] = array(	
		'desc'	=> __('Fifth Services box for frontpage section','business-web'),
		'id' 	=> 'box5',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for fifth box.', 'business-web'),
		'id' => 'boximg5',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
		
	$options[] = array(	
		'desc'	=> __('Six Services box for frontpage section','business-web'),
		'id' 	=> 'box6',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for six box.', 'business-web'),
		'id' => 'boximg6',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');	
		
	$options[] = array(	
		'desc' => __('Change read more button text for  top services four boxes ', 'business-web'),
		'id' => 'readmorebutton',
		'std' => 'Read More',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('Select excerpt length for services four boxes section', 'business-web'),
		'id' => 'pageboxlength',
		'std' => '20',
		'type' => 'text');			
	
	$options[] = array(			
			'desc'	=> __('Check to hide above our services four column section', 'business-web'),
			'id'	=> 'hidefourbxsec',
			'type'	=> 'checkbox',
			'std'	=> '');	

	$options[] = array(
		'name' => __('Number of Sections', 'business-web'),
		'desc' => __('Select number of sections', 'business-web'),
		'id' => 'numsection',
		'type' => 'select',
		'std' => '8',
		'options' => array_combine(range(1,30), range(1,30)) );

	$numsecs = of_get_option( 'numsection', 8 );

	for( $n=1; $n<=$numsecs; $n++){
		$options[] = array(
			'desc' => __("<h3>Section ".$n."</h3>", 'business-web'),
			'class' => 'toggle_title',
			'type' => 'info');	
	
		$options[] = array(
			'name' => __('Section Title', 'business-web'),
			'id' => 'sectiontitle'.$n,
			'std' => ( ( isset($section_text[$n]['section_title']) ) ? $section_text[$n]['section_title'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section ID', 'business-web'),
			'desc'	=> __('Enter your section ID here. SECTION ID MUST BE IN SMALL LETTERS ONLY AND DO NOT ADD SPACE OR SYMBOL.'),
			'id' => 'menutitle'.$n,
			'std' => ( ( isset($section_text[$n]['menutitle']) ) ? $section_text[$n]['menutitle'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section Background Color', 'business-web'),
			'desc' => __('Select background color for section', 'business-web'),
			'id' => 'sectionbgcolor'.$n,
			'std' => ( ( isset($section_text[$n]['bgcolor']) ) ? $section_text[$n]['bgcolor'] : '' ),
			'type' => 'color');
			
		$options[] = array(
			'name' => __('Background Image', 'business-web'),
			'id' => 'sectionbgimage'.$n,
			'class' => '',
			'std' => ( ( isset($section_text[$n]['bgimage']) ) ? $section_text[$n]['bgimage'] : '' ),
			'type' => 'upload');

		$options[] = array(
			'name' => __('Section CSS Class', 'business-web'),
			'desc' => __('Set class for this section.', 'business-web'),
			'id' => 'sectionclass'.$n,
			'std' => ( ( isset($section_text[$n]['class']) ) ? $section_text[$n]['class'] : '' ),
			'type' => 'text');
			
		$options[] = array(
			'name'	=> __('Hide Section', 'business-web'),
			'desc'	=> __('Check to hide this section', 'business-web'),
			'id'	=> 'hidesec'.$n,
			'type'	=> 'checkbox',
			'std'	=> '');

		$options[] = array(
			'name' => __('Section Content', 'business-web'),
			'id' => 'sectioncontent'.$n,
			'std' => ( ( isset($section_text[$n]['content']) ) ? $section_text[$n]['content'] : '' ),
			'type' => 'editor');
	}


	//SLIDER SETTINGS
	$options[] = array(
		'name' => __('Homepage Slider', 'business-web'),
		'type' => 'heading');	
		
	$options[] = array(
		'name' => __('Inner Page Banner', 'business-web'),
		'desc' => __('Upload inner page banner for site', 'business-web'),
		'id' => 'innerpagebanner',
		'class' => '',
		'std'	=> get_template_directory_uri()."/images/default-banner.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'name' => __('Custom Slider Shortcode Area For Home Page', 'business-web'),
		'desc' => __('Enter here your slider shortcode without php tag', 'business-web'),
		'id' => 'customslider',
		'std' => '',
		'type' => 'textarea');			
		
	$options[] = array(
		'name' => __('Slider Effects and Timing', 'business-web'),
		'desc' => __('Select slider effect.','business-web'),
		'id' => 'slideefect',
		'std' => 'fade',
		'type' => 'select',
		'options' => array('random'=>'Random', 'fade'=>'Fade', 'fold'=>'Fold', 'sliceDown'=>'Slide Down', 'sliceDownLeft'=>'Slide Down Left', 'sliceUp'=>'Slice Up', 'sliceUpLeft'=>'Slice Up Left', 'sliceUpDown'=>'Slice Up Down', 'sliceUpDownLeft'=>'Slice Up Down Left', 'slideInRight'=>'SlideIn Right', 'slideInLeft'=>'SlideIn Left', 'boxRandom'=>'Box Random', 'boxRain'=>'Box Rain', 'boxRainReverse'=>'Box Rain Reverse', 'boxRainGrow'=>'Box Rain Grow', 'boxRainGrowReverse'=>'Box Rain Grow Reverse' ));
		
	$options[] = array(
		'desc' => __('Animation speed should be multiple of 100.', 'business-web'),
		'id' => 'slideanim',
		'std' => 500,
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add slide pause time.', 'business-web'),
		'id' => 'slidepause',
		'std' => 4000,
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slide Controllers', 'business-web'),
		'desc' => __('Hide/Show Next, Prev arrows of slider.','business-web'),
		'id' => 'slidenav',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Hide/Show pager of slider.','business-web'),
		'id' => 'slidepage',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Pause Slide on Hover.','business-web'),
		'id' => 'slidepausehover',
		'std' => 'false',
		'type' => 'select',
		'options' => array('true'=>'Yes', 'false'=>'No'));
		
	$options[] = array(
		'name' => __('Slider Image 1', 'business-web'),
		'desc' => __('First Slide', 'business-web'),
		'id' => 'slide1',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider1.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 1', 'business-web'),
		'id' => 'slidetitle1',
		'std' => '<strong>Multipurpose</strong> Wordpress themes ',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-web'),
		'id' => 'slidedesc1',
		'std' => 'Nunc sed lorem pretium, volutpat tortor id, adipiscing sem. Sed bibendum quis augue nec porta. Ut molestie tortor pulvinar, faucibus justo vitae, interdum nunc. Vestibulum imperdiet nisl vel condimentum faucibus. Vivamus rutrum ipsum vel luctus. ',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-web'),
		'id' => 'slidebutton1',
		'std' => 'Read More &raquo;',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url', 'business-web'),
		'id' => 'slideurl1',
		'std' => '#',
		'type' => 'text');		
		
	
	$options[] = array(
		'name' => __('Slider Image 2', 'business-web'),
		'desc' => __('Second Slide', 'business-web'),
		'class' => '',
		'id' => 'slide2',
		'std' => get_template_directory_uri()."/images/slides/slider2.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 2', 'business-web'),
		'id' => 'slidetitle2',
		'std' => '<strong>Responsive</strong> Wordpress themes',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-web'),
		'id' => 'slidedesc2',
		'std' => 'Nunc sed lorem pretium, volutpat tortor id, adipiscing sem. Sed bibendum quis augue nec porta. Ut molestie tortor pulvinar, faucibus justo vitae, interdum nunc. Vestibulum imperdiet nisl vel condimentum faucibus. Vivamus rutrum ipsum vel luctus. ',
		'type' => 'textarea');	
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-web'),
		'id' => 'slidebutton2',
		'std' => 'Read More &raquo;',
		'type' => 'text');	
			
	$options[] = array(
		'desc' => __('Slide Url', 'business-web'),
		'id' => 'slideurl2',
		'std' => '#',
		'type' => 'text');	
	
		
	$options[] = array(
		'name' => __('Slider Image 3', 'business-web'),
		'desc' => __('Third Slide', 'business-web'),
		'id' => 'slide3',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider3.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 3', 'business-web'),
		'id' => 'slidetitle3',
		'std' => 'Easy <strong> Customization </strong> theme option',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-web'),
		'id' => 'slidedesc3',
		'std' => 'Nunc sed lorem pretium, volutpat tortor id, adipiscing sem. Sed bibendum quis augue nec porta. Ut molestie tortor pulvinar, faucibus justo vitae, interdum nunc. Vestibulum imperdiet nisl vel condimentum faucibus. Vivamus rutrum ipsum vel luctus.',
		'type' => 'textarea');	
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-web'),
		'id' => 'slidebutton3',
		'std' => 'Read More &raquo;',
		'type' => 'text');	
	
	$options[] = array(
		'desc' => __('Slide Url', 'business-web'),
		'id' => 'slideurl3',
		'std' => '#',
		'type' => 'text');	
			
	
	$options[] = array(
		'name' => __('Slider Image 4', 'business-web'),
		'desc' => __('Fourth Slide', 'business-web'),
		'id' => 'slide4',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 4', 'business-web'),
		'id' => 'slidetitle4',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-web'),
		'id' => 'slidedesc4',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-web'),
		'id' => 'slidebutton4',
		'std' => '',
		'type' => 'text');	
				
		
	$options[] = array(
		'desc' => __('Slide Url', 'business-web'),
		'id' => 'slideurl4',
		'std' => '',
		'type' => 'text');				
	
	$options[] = array(
		'name' => __('Slider Image 5', 'business-web'),
		'desc' => __('Fifth Slide', 'business-web'),
		'id' => 'slide5',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 5', 'business-web'),
		'id' => 'slidetitle5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-web'),
		'id' => 'slidedesc5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-web'),
		'id' => 'slidebutton5',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url', 'business-web'),
		'id' => 'slideurl5',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 6', 'business-web'),
		'desc' => __('Sixth Slide', 'business-web'),
		'id' => 'slide6',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
		
	$options[] = array(
		'desc' => __('Title 6', 'business-web'),
		'id' => 'slidetitle6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-web'),
		'id' => 'slidedesc6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-web'),
		'id' => 'slidebutton6',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url', 'business-web'),
		'id' => 'slideurl6',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 7', 'business-web'),
		'desc' => __('Seventh Slide', 'business-web'),
		'id' => 'slide7',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 7', 'business-web'),
		'id' => 'slidetitle7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-web'),
		'id' => 'slidedesc7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-web'),
		'id' => 'slidebutton7',
		'std' => '',
		'type' => 'text');					
		
	$options[] = array(
		'desc' => __('Slide Url', 'business-web'),
		'id' => 'slideurl7',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 8', 'business-web'),
		'desc' => __('Eighth Slide', 'business-web'),
		'id' => 'slide8',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 8', 'business-web'),
		'id' => 'slidetitle8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-web'),
		'id' => 'slidedesc8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-web'),
		'id' => 'slidebutton8',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url', 'business-web'),
		'id' => 'slideurl8',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 9', 'business-web'),
		'desc' => __('Ninth Slide', 'business-web'),
		'id' => 'slide9',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 9', 'business-web'),
		'id' => 'slidetitle9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-web'),
		'id' => 'slidedesc9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-web'),
		'id' => 'slidebutton9',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url', 'business-web'),
		'id' => 'slideurl9',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 10', 'business-web'),
		'desc' => __('Tenth Slide', 'business-web'),
		'id' => 'slide10',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 10', 'business-web'),
		'id' => 'slidetitle10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-web'),
		'id' => 'slidedesc10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-web'),
		'id' => 'slidebutton10',
		'std' => '',
		'type' => 'text');					
	
	$options[] = array(
		'desc' => __('Slide Url', 'business-web'),
		'id' => 'slideurl10',
		'std' => '',
		'type' => 'text');

	//Footer SETTINGS
	$options[] = array(
		'name' => __('Footer', 'business-web'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Footer Layout', 'business-web'),
		'desc' => __('footer Select layout. eg:Boxed, 1, 2, 3 and 4', 'business-web'),
		'id' => 'footerlayout',
		'type' => 'select',
		'std' => 'fourcolumn',
		'options' => array('onecolumn'=>'Footer 1 column', 'twocolumn'=>'Footer 2 column', 'threecolumn'=>'Footer 3 column', 'fourcolumn'=>'Footer 4 column', ) );		
				
	$options[] = array(
		'name' => __('Footer About Us', 'business-web'),
		'desc' => __('about us text title for footer', 'business-web'),
		'id' => 'aboutustitle',
		'std' => 'About Us',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('About kraft Description', 'business-web'),
		'desc' => __('about kraft text description for footer', 'business-web'),
		'id' => 'aboutdescription',
		'std' => '<p>Nam aliquet aliquam ipsum eget volutpat. Duis nec porta purus. Integer adipiscing augue sit amet libero vulputate, et fermentum nibh rutrum. In bibendum nisi sed consequat hendrerit. Aliquam.</p>
<p>Quisque elementum, dolor nec tempus eleifend, nibh mauris aliquet ante, eu tempus sapien nisi non nunc. Nulla facilisi. </p> ',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Our Menu', 'business-web'),
		'desc' => __('Footer menu title.', 'business-web'),
		'id' => 'usefullinktitle',
		'std' => 'Our Menu',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __(' Recent Posts Title', 'business-web'),
		'desc' => __('recent posts title for footer.', 'business-web'),
		'id' => 'frptitle',
		'std' => 'Recent Posts',
		'type' => 'text');	
		
		
	$options[] = array(
		'name' => __('Footer Address Title', 'business-web'),
		'desc' => __('Add contact title here', 'business-web'),
		'id' => 'contacttitle',
		'std' => 'Contact Info',
		'type' => 'text');	
		
	$options[] = array(	
		'desc' => __('Add company address1 here.', 'business-web'),
		'id' => 'address',
		'std' => '100 King St, Melbourne PIC 4000,',
		'type' => 'text');
		
	$options[] = array(	
		'desc' => __('Add company address2 here.', 'business-web'),
		'id' => 'address2',
		'std' => 'Australia',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('Add phone number here.', 'business-web'),
		'id' => 'phone',
		'std' => '+1 800 234 5678',
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add email address here.', 'business-web'),
		'id' => 'email',
		'std' => 'info@sitename.com',
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add company url here with http://.', 'business-web'),
		'id' => 'weblink',
		'std' => 'http://demo.com',
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('add social icon name and link in the shortcodes.', 'business-web'),
		'id' => 'footersocialicons',
		'std' => '[social_area]
    [social icon="facebook" link="#"]
    [social icon="twitter" link="#"]
    [social icon="linkedin" link="#"]
    [social icon="pinterest" link="#"]
    [social icon="google-plus" link="#"]	
[/social_area]',
		'type' => 'textarea');		
		
	$options[] = array(
		'name' => __('Footer Copyright', 'business-web'),
		'desc' => __('Copyright Text for your site.', 'business-web'),
		'id' => 'copytext',
		'std' => '&copy; 2016 <a href="#">Business Web. </a> All Rights Reserved',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Footre Text Link', 'business-web'),
		'id' => 'ftlink',
		'std' => 'Design by <a href="'.esc_url('https://www.gracethemes.com/').'" target="_blank">Grace Themes</a>',
		'type' => 'textarea',);
		
	$options[] = array(
		'desc' => __('Footer Back to Top Button', 'business-web'),
		'id' => 'backtotop',
		'std' => '[back-to-top]',
		'type' => 'textarea',);		

	//Short codes
	$options[] = array(
		'name' => __('Short Codes', 'business-web'),
		'type' => 'heading');	
		
	
	$options[] = array(
		'name' => __('Photo Gallery', 'business-web'),
		'desc' => __('[photogallery filter="true"]', 'business-web'),
		'type' => 'info');			
			
		
	$options[] = array(
		'name' => __('Testimonials', 'business-web'),
		'desc' => __('[testimonials]', 'business-web'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Contact Form', 'business-web'),
		'desc' => __('[contactform to_email="test@example.com" title="Contact Form"] 
', 'business-web'),
		'type' => 'info');		
		
	$options[] = array(
		'name' => __('Footer posts', 'business-web'),
		'desc' => __('[footer-posts show="2"]', 'business-web'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Team Member', 'business-web'),
		'desc' => __('[ourteam show="4"]', 'business-web'),
		'type' => 'info');					
	
				
	$options[] = array(
		'name' => __('Search Form', 'business-web'),
		'desc' => __('[searchform] 
', 'business-web'),
		'type' => 'info');
			
		
	$options[] = array(
		'name' => __('Headings', 'business-web'),
		'desc' => __('[heading underline="yes" align="left"]Our Team[/heading]', 'business-web'),
		'type' => 'info');					

	$options[] = array(
		'name' => __('View More Button', 'business-web'),
		'desc' => __('[readmore-link align="left" button="Read More" links="#" target=""]', 'business-web'),
		'type' => 'info');	

		
	$options[] = array(
		'name' => __('Social Icons ( Note: More social icons can be found at: http://fortawesome.github.io/Font-Awesome/icons/)', 'business-web'),
		'desc' => __('[social_area]
    [social icon="facebook" link="#"]
    [social icon="twitter" link="#"]
    [social icon="linkedin" link="#"]
    [social icon="pinterest" link="#"]
    [social icon="google-plus" link="#"]
	[social icon="youtube" link="#"]
	[social icon="wordpress" link="#"]
	[social icon="flickr" link="#"]
	[social icon="skype" link="#"]
[/social_area]', 'business-web'),
		'type' => 'info');	
		
		

	$options[] = array(
		'name' => __('2 Column Content', 'business-web'),
		'desc' => __('<pre>
[column_content type="one_half"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_half_last"]
	Column 2 Content goes here...
[/column_content]
</pre>', 'business-web'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('3 Column Content', 'business-web'),
		'desc' => __('<pre>
[column_content type="one_third"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_third"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_third_last"]
	Column 3 Content goes here...
[/column_content]
</pre>', 'business-web'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('4 Column Content', 'business-web'),
		'desc' => __('<pre>
[column_content type="one_fourth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fourth_last"]
	Column 4 Content goes here...
[/column_content]
</pre>', 'business-web'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('5 Column Content', 'business-web'),
		'desc' => __('<pre>
[column_content type="one_fifth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 4 Content goes here...
[/column_content]

[column_content type="one_fifth_last"]
	Column 5 Content goes here...
[/column_content]
</pre>', 'business-web'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('Clear', 'business-web'),
		'desc' => __('<pre>
[clear]
</pre>', 'business-web'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('HR / Horizontal separation line', 'business-web'),
		'desc' => __('<pre>
[hr] or &lt;hr&gt;
</pre>', 'business-web'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Separator / blank space', 'business-web'),
		'desc' => __('<pre>
[separator height="20"]
</pre>', 'business-web'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Blank space without image', 'business-web'),
		'desc' => __('<pre>
[blankspace height="20"]
</pre>', 'business-web'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Tabs', 'business-web'),
		'desc' => __('<pre>
[tabs]
	[tab title="TAB TITLE 1"]
		TAB CONTENT 1
	[/tab]
	[tab title="TAB TITLE 2"]
		TAB CONTENT 2
	[/tab]
	[tab title="TAB TITLE 3"]
		TAB CONTENT 3
	[/tab]
[/tabs]
</pre>', 'business-web'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Toggle Content', 'business-web'),
		'desc' => __('<pre>
[toggle_content title="Toggle Title 1"]
	Toggle content 1...
[/toggle_content]
[toggle_content title="Toggle Title 2"]
	Toggle content 2...
[/toggle_content]
[toggle_content title="Toggle Title 3"]
	Toggle content 3...
[/toggle_content]
</pre>', 'business-web'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Accordion Content', 'business-web'),
		'desc' => __('<pre>
[accordion]
	[accordion_content title="ACCORDION TITLE 1"]
		ACCORDION CONTENT 1
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 2"]
		ACCORDION CONTENT 2
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 3"]
		ACCORDION CONTENT 3
	[/accordion_content]
[/accordion]
</pre>', 'business-web'),
		'type' => 'info');

	$options[] = array(
		'name' => __('List Styles', 'business-web'),
		'desc' => __('<pre>
[unordered_list style="list-1"]&lt;li&gt;List style 1&lt;/li&gt;[/unordered_list]
</pre>
<br />You can use above shortcode OR simply add class to ul. You can choose from list-1 to list-10 styles.<br />
<pre>
&lt;ul class="list-1"&gt;&lt;li&gt;List style 1&lt;/li&gt;&lt;/ul&gt;
</pre>
', 'business-web'),
		'type' => 'info');
		
	
	$options[] = array(
		'name' => __('Horizontal Separator', 'business-web'),
		'desc' => __('[hr_top] 
', 'business-web'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Back to Top', 'business-web'),
		'desc' => __('[back-to-top]', 'business-web'),
		'type' => 'info');	
		
	
	// Support					
	$options[] = array(
		'name' => __('Our Themes', 'business-web'),
		'type' => 'heading');

	$options[] = array(
		'desc' => __('Business Web WordPress theme has been Designed and Created by <a href="'.esc_url('https://gracethemes.com/').'" target="_blank">Grace Themes</a>', 'business-web'),
		'type' => 'info');	

	 $options[] = array(
		'desc' => __('<a href="'.esc_url('https://gracethemes.com/').'" target="_blank"><img src="'.get_template_directory_uri().'/images/themesbunch.jpg"></a>', 'business-web'),
		'type' => 'info');	

	return $options;
}